@@ -40,10 +40,34 @@ enum DuplexType
 
 Q_DECLARE_METATYPE(DuplexType)
 
-QString duplexTypetoStr(DuplexType value);
+QString duplexTypeToStr(DuplexType value);
 DuplexType strToDuplexType(const QString &str);
 
 
+enum class FlipType
+{
+    ShortEdge,
+    LongEdge
+};
+
+Q_DECLARE_METATYPE(FlipType)
+
+QString flipTypeToStr(FlipType value);
+FlipType strToFlipType(const QString &str);
+
+enum ColorMode
+{
+    ColorModeAuto       = 0,
+    ColorModeColor      = 1,
+    ColorModeGrayscale  = 2
+};
+
+Q_DECLARE_METATYPE(ColorMode)
+
+QString colorModeToStr(ColorMode value);
+ColorMode strToColorMode(const QString &str);
+
+
 enum Rotation
 {
     NoRotate  = 0,
@@ -103,5 +127,9 @@ T* findExistingForm()
     return 0;
 }
 
+QString safeFileName(const QString &str);
+
+QString expandHomeDir(const QString &fileName);
+QString shrinkHomeDir(const QString &fileName);
 
 #endif // BOOMAGATYPES_H
