@@ -25,14 +25,13 @@
 
 
 #include "job.h"
-#include "project.h"
-#include "boomagapoppler.h"
+#include "projectpage.h"
 
 #include <QDebug>
 #include <QIODevice>
 #include <QFileInfo>
 #include "kernel/inputfile.h"
-#include "kernel/boomagapoppler.h"
+#include "pdfparser/pdfreader.h"
 #include <QSharedDataPointer>
 
 #define LOCK_CHECK          0
@@ -77,12 +76,13 @@ JobData::JobData(const QString &fileName, qint64 startPos, qint64 endPos, const
         if (!mEndPos)
             mEndPos = fi.size();
 
-        BoomagaPDFDoc *doc = new BoomagaPDFDoc(fi.absoluteFilePath(), mStartPos, mEndPos);
-
-        if (doc->isValid())
+        try
         {
-            mTitle = doc->getMetaInfo("Title");
-            int pageCount = doc->getNumPages();
+            PDF::Reader reader;
+            reader.open(fi.absoluteFilePath(), mStartPos, mEndPos);
+
+            mTitle = reader.find("/Trailer/Info/Title").asString().value();
+            int pageCount = reader.pageCount();
 
             InputFile inputFile(mFileName, mStartPos, mEndPos);
 
@@ -110,15 +110,13 @@ JobData::JobData(const QString &fileName, qint64 startPos, qint64 endPos, const
 
             mState = Job::JobNotReady;
         }
-        else
+        catch (const PDF::Error &err)
         {
             mState = Job::JobError;
-            mErrorString = doc->errorString();
+            mErrorString = err.what();
         }
-
-        delete doc;
-        lockUnlockFile(mFileName, LOCK_CREATE);
     }
+    lockUnlockFile(mFileName, LOCK_CREATE);
 }
 
 
@@ -303,7 +301,6 @@ int Job::indexOfPage(const ProjectPage *page, int from) const
 void Job::insertPage(int before, ProjectPage *page)
 {
     mData->mPages.insert(before, page);
-    project->update();
 }
 
 
@@ -313,7 +310,6 @@ void Job::insertPage(int before, ProjectPage *page)
 void Job::addPage(ProjectPage *page)
 {
     mData->mPages.append(page);
-    project->update();
 }
 
 
@@ -323,7 +319,6 @@ void Job::addPage(ProjectPage *page)
 void Job::removePage(ProjectPage *page)
 {
     ProjectPage *p = mData->takePage(page);
-    project->update();
     delete p;
 }
 
@@ -338,8 +333,6 @@ void Job::removePages(const QList<ProjectPage*> pages)
         ProjectPage *p = mData->takePage(page);
         delete p;
     }
-
-    project->update();
 }
 
 
@@ -352,8 +345,6 @@ ProjectPage *Job::takePage(ProjectPage *page)
     if (n>-1)
     {
         ProjectPage *page = mData->mPages.takeAt(n);
-
-        project->update();
         return page;
     }
     else
@@ -439,9 +430,11 @@ void Job::setAutoRemove(bool value)
 /************************************************
  *
  * ***********************************************/
-void Job::insertBlankPage(int before)
+ProjectPage *Job::insertBlankPage(int before)
 {
-    insertPage(before, new ProjectPage());
+    ProjectPage *page = new ProjectPage();
+    insertPage(before, page);
+    return page;
 }
 
 
@@ -453,7 +446,7 @@ Job Job::clone()
     Job res = *this;
     res.mData.detach();
     for (int i=0; i< mData->mPages.count(); ++i)
-        res.mData->mPages[i] = new ProjectPage(mData->mPages.at(i));
+        res.mData->mPages[i] = mData->mPages.at(i)->clone();
 
     return res;
 }
@@ -483,6 +476,9 @@ JobList::JobList(const QList<Job> &other):
  ************************************************/
 int JobList::indexOfProjectPage(const ProjectPage * page, int from) const
 {
+    if (!page)
+        return -1;
+
     for(int i=from; i<this->count(); ++i)
     {
         if (at(i).indexOfPage(page) > -1)
