@@ -71,9 +71,17 @@ public:
     bool reverseOrder() const { return mReverseOrder; }
     void setReverseOrder(bool value);
 
+    ColorMode colorMode() const { return mColorMode; }
+    void setColorMode(ColorMode value);
+
+    bool grayscale() const { return mColorMode == ColorModeGrayscale; }
+
     QSizeF paperSize(Unit unit) const;
     void setPaperSize(const QSizeF & paperSize, Unit unit);
 
+    FlipType flipType() const { return mFlipType; }
+    void setFlipType(FlipType value);
+
     void readSettings();
     void saveSettings() const;
 
@@ -88,7 +96,8 @@ private:
     bool mDrawBorder;
     bool mReverseOrder;
     QSizeF mPaperSize;
-
+    ColorMode mColorMode;
+    FlipType mFlipType;
 };
 
 
@@ -100,13 +109,15 @@ public:
 
     virtual QString name() const { return mPrinterName; }
 
-    QVector<PrinterProfile> *profiles() { return &mProfiles; }
-    const QVector<PrinterProfile> *profiles() const { return &mProfiles; }
+    QVector<PrinterProfile> profiles() { return mProfiles; }
+    const QVector<PrinterProfile> profiles() const { return mProfiles; }
+    void setProfiles(const QVector<PrinterProfile> &value);
 
-    int currentProfile() const { return mCurrentProfileIndex; }
+    PrinterProfile *currentProfile() const { return mCurrentProfile; }
+    int currentProfileIndex() const { return mCurrentProfileIndex; }
     void setCurrentProfile(int index);
 
-    const PrinterProfile *cupsProfile() const { return &mCupsProfile; }
+    const PrinterProfile *defaultCupsProfile() const { return &mDefaultCupsProfile; }
 
     QSizeF paperSize(Unit unit) const { return mCurrentProfile->paperSize(unit); }
     void setPaperSize(const QSizeF & paperSize, Unit unit) { mCurrentProfile->setPaperSize(paperSize, unit); }
@@ -138,11 +149,19 @@ public:
     bool reverseOrder() const        { return mCurrentProfile->reverseOrder(); }
     void setReverseOrder(bool value) { mCurrentProfile->setReverseOrder(value); }
 
+    ColorMode colorMode() const { return mCurrentProfile->colorMode(); }
+    void setColorMode(ColorMode value) { mCurrentProfile->setColorMode(value); }
+
+    bool grayscale() const { return mCurrentProfile->grayscale(); }
+    bool isSupportColor() const;
+
+    FlipType flipType() const { return mCurrentProfile->flipType(); }
+    void setFlipType(FlipType value) { mCurrentProfile->setFlipType(value);}
+
     bool canChangeDuplexType() const { return mCanChangeDuplexType; }
     bool isShowProgressDialog() const { return mShowProgressDialog; }
 
-
-    virtual bool print(const QList<Sheet*> &sheets, const QString &jobName, bool duplex, int numCopies = 1) const;
+    virtual bool print(const QList<Sheet*> &sheets, const QString &jobName, bool duplex, int numCopies, bool collate) const;
 
     QString deviceUri() const { return mDeviceUri; }
 
@@ -163,7 +182,9 @@ private:
     QVector<PrinterProfile> mProfiles;
     int mCurrentProfileIndex;
     PrinterProfile *mCurrentProfile;
-    PrinterProfile mCupsProfile;
+    PrinterProfile mDefaultCupsProfile;
+    QString mGrayscaleOption;
+    QString mColorOption;
 };
 
 #endif // PRINTER_H
