@@ -42,7 +42,6 @@
 #include "render.h"
 
 
-
 /************************************************
 
  ************************************************/
@@ -84,8 +83,7 @@ QString TmpPdfFile::genFileName()
 TmpPdfFile::TmpPdfFile(const JobList &jobs, QObject *parent):
     QObject(parent),
     mMerger(0),
-    mValid(false),
-    mRender(0)
+    mValid(false)
 {
     mOrigFileSize = 0;
     mOrigXrefPos = 0;
@@ -103,7 +101,6 @@ TmpPdfFile::TmpPdfFile(const JobList &jobs, QObject *parent):
  ************************************************/
 TmpPdfFile::~TmpPdfFile()
 {
-    delete mRender;
     delete mMerger;
     QFile::remove(mFileName);
 }
@@ -114,6 +111,7 @@ TmpPdfFile::~TmpPdfFile()
  ************************************************/
 void TmpPdfFile::merge()
 {
+    delete mMerger;
     mMerger = new QProcess(this);
 
     connect(mMerger, SIGNAL(finished(int)),
@@ -150,7 +148,7 @@ void TmpPdfFile::merge()
     {
         QStringList dirs;
         dirs << QApplication::applicationDirPath() + "/";
-        dirs << QApplication::applicationDirPath() + "/../lib/boomaga/";
+        dirs << NONGUI_DIR  "/";
 
         foreach (QString dir, dirs)
         {
@@ -178,12 +176,6 @@ void TmpPdfFile::merge()
  ************************************************/
 void TmpPdfFile::updateSheets(QList<Sheet *> &sheets)
 {
-    if (mRender)
-    {
-        delete mRender;
-        mRender = 0;
-    }
-
     if (mValid)
     {
         QFile file(mFileName);
@@ -199,11 +191,6 @@ void TmpPdfFile::updateSheets(QList<Sheet *> &sheets)
 
         file.resize(file.pos());
         file.close();
-
-        mRender = new Render(mFileName);
-        connect(mRender, SIGNAL(imageChanged(int)),
-                this, SIGNAL(imageChanged(int)));
-        mRender->start();
    }
 }
 
@@ -269,15 +256,15 @@ void TmpPdfFile::writeSheets(QIODevice *out, const QList<Sheet *> &sheets) const
     qint32 num = pagesNum + 1;
     foreach(const Sheet *sheet, sheets)
     {
-        int pegeNum      = num;
+        int pageNum      = num;
         int resourcesNum = num + 1;
         int contentsNum  = num + 2;
         num += 3;
 
 
         // Page ............................
-        xref.insert(pegeNum, out->pos());
-        *out << pegeNum << " 0 obj\n";
+        xref.insert(pageNum, out->pos());
+        *out << pageNum << " 0 obj\n";
         *out << "<<\n";
         *out << "/Type /Page\n";
         *out << "/Contents "  << contentsNum  << " 0 R\n";
@@ -288,7 +275,7 @@ void TmpPdfFile::writeSheets(QIODevice *out, const QList<Sheet *> &sheets) const
         *out << ">>\n";
         *out << "endobj\n";
 
-        pagesKids << QString("%1 0 R").arg(pegeNum);
+        pagesKids << QString("%1 0 R").arg(pageNum);
         //..................................
 
 
@@ -300,9 +287,12 @@ void TmpPdfFile::writeSheets(QIODevice *out, const QList<Sheet *> &sheets) const
         for (int i=0; i< sheet->count(); ++i)
         {
             const ProjectPage *page = sheet->page(i);
-            if (page && page->pdfInfo().objNum)
+            if (!page)
+                continue;
+
+            for (int j=0; j<page->pdfInfo().xObjNums.count(); ++j)
             {
-                *out << "/Im" << i << " " << page->pdfInfo().objNum <<  " 0 R ";
+                *out << "/Im" << i << "_" << j << " " << page->pdfInfo().xObjNums.at(j) <<  " 0 R ";
             }
         }
         *out << ">>\n";
@@ -477,6 +467,10 @@ void TmpPdfFile::getPageStream(QString *out, const Sheet *sheet) const
                     .arg(-page->rect().top(), 0, 'f', 3);
 
 
+            for (int j=0; j<page->pdfInfo().xObjNums.size(); ++j)
+                *out += QString("/Im%1_%2 Do\n").arg(i).arg(j);
+
+
             if (printer->drawBorder())
             {
                 *out += QString("%1 %2 %3 %4 re\nS\n")
@@ -486,8 +480,6 @@ void TmpPdfFile::getPageStream(QString *out, const Sheet *sheet) const
                         .arg(page->rect().height(), 0, 'f', 3);
             }
 
-            if (page->pdfInfo().objNum)
-                *out += QString("/Im%1 Do\n").arg(i);
 
             *out += "Q\n";
             *out += "Q\n";
@@ -501,7 +493,7 @@ void TmpPdfFile::getPageStream(QString *out, const Sheet *sheet) const
 /************************************************
 
  ************************************************/
-void TmpPdfFile::mergerFinished(int exitCode)
+void TmpPdfFile::mergerFinished(int)
 {
     mValid = (mMerger->exitCode() == 0 ) &&
              (mMerger->exitStatus() == QProcess::NormalExit);
@@ -539,18 +531,6 @@ void TmpPdfFile::ipcXRefInfo(qint64 xrefPos, qint32 freeNum)
 }
 
 
-/************************************************
-
- ************************************************/
-QImage TmpPdfFile::image(int sheetNum) const
-{
-    if (mRender)
-        return mRender->image(sheetNum);
-    else
-        return QImage();
-}
-
-
 /************************************************
  *
  * ***********************************************/
@@ -558,6 +538,3 @@ PdfPageInfo TmpPdfFile::pageInfo(InputFile file, int pageNum)
 {
     return mPagesInfo.value(QString("%1:%2").arg(mInputFiles.indexOf(file)).arg(pageNum));
 }
-
-
-
