@@ -35,12 +35,12 @@
 #include "printersettings/printersettings.h"
 #include "aboutdialog/aboutdialog.h"
 #include "actions.h"
-#include "export/exporttopdfprinter.h"
 #include "icon.h"
 #include "configdialog/configdialog.h"
 #include "boomagatypes.h"
 #include "export/exporttopdf.h"
 #include "printdialog/printdialog.h"
+#include "boomagatypes.h"
 
 #include <math.h>
 #include <QRadioButton>
@@ -54,6 +54,8 @@
 #include <QFileDialog>
 #include <QMimeData>
 #include <QInputDialog>
+#include <QDateTime>
+#include <QMenu>
 
 
 /************************************************
@@ -64,15 +66,13 @@ MainWindow::MainWindow(QWidget *parent):
     ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
+    this->setContextMenuPolicy(Qt::NoContextMenu);
 
     setWindowIcon(Icon::icon(Icon::ApplicationIcon));
     setWindowTitle(tr("Boomaga"));
 
     setStyleSheet("QListView::item { padding: 2px;}");
 
-    mExportPrinter = new ExportToPDFPrinter();
-    fillPrintersCombo();
-
     initStatusBar();
     initActions();
 
@@ -104,11 +104,9 @@ MainWindow::MainWindow(QWidget *parent):
     mAvailableLayouts << layout;
     ui->layoutBookletBtn->setLayout(layout);
 
-
     loadSettings();
-    switchPrinterProfile();
-    updateWidgets();
-    updateWidgets();
+    fillPrintersCombo();
+
 
     connect(ui->layout1UpBtn,     SIGNAL(clicked(bool)),
             this, SLOT(switchLayout()));
@@ -134,8 +132,11 @@ MainWindow::MainWindow(QWidget *parent):
     connect(ui->doubleSidedCbx, SIGNAL(clicked(bool)),
             project, SLOT(setDoubleSided(bool)));
 
-    connect(ui->jobsView, SIGNAL(jobSelected(Job)),
-            this, SLOT(switchToJob(Job)));
+    connect(ui->jobsView, SIGNAL(pageSelected(int)),
+            project, SLOT(setCurrentPage(int)));
+
+    connect(ui->subBookletView, SIGNAL(pageSelected(int)),
+            project, SLOT(setCurrentPage(int)));
 
     connect(ui->printersCombo, SIGNAL(activated(int)),
             this, SLOT(switchPrinterProfile()));
@@ -143,24 +144,37 @@ MainWindow::MainWindow(QWidget *parent):
     connect(project, SIGNAL(changed()),
             this, SLOT(updateWidgets()));
 
+    connect(project, SIGNAL(currentPageChanged(int)),
+            this, SLOT(updateWidgets()));
+
+
+    connect(project, SIGNAL(changed()),
+            ui->preview, SLOT(refresh()));
+
+    connect(project, SIGNAL(currentPageChanged(int)),
+            ui->preview, SLOT(refresh()));
+
     connect(ui->printerConfigBtn, SIGNAL(clicked()),
             this, SLOT(showPrinterSettingsDialog()));
 
     connect(project, SIGNAL(progress(int,int)),
             this, SLOT(updateProgressBar(int, int)), Qt::QueuedConnection);
 
-    connect(ui->preview, SIGNAL(changed(int)),
-            this, SLOT(updateWidgets()));
-
-    connect(ui->preview, SIGNAL(changed(int)),
-            ui->jobsView, SLOT(setSheetNum(int)));
-
-    connect(ui->preview, SIGNAL(contextMenuRequested(int)),
-            this, SLOT(showPreviewContextMenu(int)));
+    connect(ui->preview, SIGNAL(contextMenuRequested(Sheet*,ProjectPage*)),
+            this, SLOT(showPreviewContextMenu(Sheet*,ProjectPage*)));
 
     connect(ui->jobsView, SIGNAL(contextMenuRequested(Job)),
             this, SLOT(showJobViewContextMenu(Job)));
 
+    connect(ui->menuFile, SIGNAL(aboutToShow()),
+            this, SLOT(fillRecentFiles()));
+
+    connect(ui->menuEditPage, SIGNAL(aboutToShow()),
+            this, SLOT(showEditPageMainMenu()));
+
+    connect(ui->menuEditJob, SIGNAL(aboutToShow()),
+            this, SLOT(showEditJobMainMenu()));
+
     ui->preview->setFocusPolicy(Qt::StrongFocus);
     ui->preview->setFocus();
 
@@ -184,40 +198,23 @@ MainWindow::~MainWindow()
  ************************************************/
 void MainWindow::fillPrintersCombo()
 {
-    PrintersComboBox *combo = ui->printersCombo;
-
-    Printer *prevPrinter = combo->currentPrinter();
-    int prevProfile = combo->currentProfile();
-
-    combo->setUpdatesEnabled(false);
-    combo->clear();
+    ui->printersCombo->setUpdatesEnabled(false);
+    ui->printersCombo->clear();
 
     foreach(Printer *printer, Printer::availablePrinters())
     {
-        combo->addPrinter(printer);
+        ui->printersCombo->addPrinter(printer);
     }
 
-    combo->insertSeparator(99999);
-    combo->addPrinter(mExportPrinter);
-
-    int index = combo->findItem(prevPrinter, prevProfile);
-
-    if (index < 0)
-        index = combo->findItem(prevPrinter, 0);
-
-    if (index < 0)
-        index = combo->findFirstProfile();
-
-
-    combo->setCurrentIndex(index);
     ui->printersCombo->setUpdatesEnabled(true);
+    updateWidgets();
 }
 
 
 /************************************************
 
  ************************************************/
-void MainWindow::closeEvent(QCloseEvent *event)
+void MainWindow::closeEvent(QCloseEvent*)
 {
     project->free();
 }
@@ -260,8 +257,11 @@ void MainWindow::loadSettings()
 {
     restoreGeometry(settings->value(Settings::MainWindow_Geometry).toByteArray());
     restoreState(settings->value(Settings::MainWindow_State).toByteArray());
+    ui->optionsPanel->setGeometry(0, 0, settings->value(Settings::MainWindow_SplitterPos, 0).toInt(), 0);
+    ui->pagesViewTab->setCurrentIndex(settings->value(Settings::MainWindow_PageListTab).toInt());
 
-    Printer *currentPrinter = Printer::printerByName(settings->value(Settings::Printer).toString());
+    QString s = settings->value(Settings::Printer).toString();
+    Printer *currentPrinter = Printer::printerByName(s);
     if (!currentPrinter)
     {
         QList<Printer*> pl = Printer::availablePrinters();
@@ -272,9 +272,7 @@ void MainWindow::loadSettings()
     if (!currentPrinter)
         currentPrinter = Printer::nullPrinter();
 
-    ui->printersCombo->setCurrentPrinterProfile(currentPrinter->name(), currentPrinter->currentProfile());
-    if (ui->printersCombo->currentIndex() < 1)
-        ui->printersCombo->setCurrentIndex(ui->printersCombo->findFirstProfile());
+    project->setPrinterProfile(currentPrinter, currentPrinter->currentProfileIndex(), false);
 
     QString layoutId = settings->value(Settings::Layout).toString();
 
@@ -288,6 +286,9 @@ void MainWindow::loadSettings()
         project->setLayout(mAvailableLayouts.at(0));
 
     project->setDoubleSided(settings->value(Settings::DoubleSided).toBool());
+
+    ui->jobsView->setIconSize(settings->value(Settings::MainWindow_PageListIconSize).toInt());
+    ui->subBookletView->setIconSize(settings->value(Settings::MainWindow_PageListIconSize).toInt());
 }
 
 
@@ -298,6 +299,8 @@ void MainWindow::saveSettings()
 {
     settings->setValue(Settings::MainWindow_Geometry, saveGeometry());
     settings->setValue(Settings::MainWindow_State, saveState());
+    settings->setValue(Settings::MainWindow_SplitterPos, ui->optionsPanel->width());
+    settings->setValue(Settings::MainWindow_PageListTab, ui->pagesViewTab->currentIndex());
 
     Printer *printer = ui->printersCombo->currentPrinter();
     if (printer)
@@ -306,9 +309,12 @@ void MainWindow::saveSettings()
     settings->setValue(Settings::Layout, project->layout()->id());
     settings->setValue(Settings::DoubleSided, project->doubleSided());
 
+
     if (project->printer() != Printer::nullPrinter())
         project->printer()->saveSettings();
 
+    settings->setValue(Settings::MainWindow_PageListIconSize, ui->jobsView->iconSize());
+    settings->setValue(Settings::MainWindow_PageListIconSize, ui->subBookletView->iconSize());
     settings->sync();
 }
 
@@ -334,7 +340,6 @@ void MainWindow::initActions()
     connect(act, SIGNAL(triggered()),
             this, SLOT(printWithOptions()));
 
-
     act = ui->actionExit;
     connect(act, SIGNAL(triggered()),
             this, SLOT(close()));
@@ -342,12 +347,12 @@ void MainWindow::initActions()
     act = ui->actionPreviousSheet;
     act->setIcon(Icon::icon(Icon::Previous));
     connect(act, SIGNAL(triggered()),
-            ui->preview, SLOT(prevSheet()));
+            project, SLOT(prevSheet()));
 
     act = ui->actionNextSheet;
     act->setIcon(Icon::icon(Icon::Next));
     connect(act, SIGNAL(triggered()),
-            ui->preview, SLOT(nextSheet()));
+            project, SLOT(nextSheet()));
 
     act = ui->actionOpen;
     act->setIcon(Icon::icon(Icon::Open));
@@ -377,6 +382,8 @@ void MainWindow::initActions()
     act = ui->actionAbout;
     connect(act, SIGNAL(triggered()),
             this, SLOT(showAboutDialog()));
+
+
 }
 
 
@@ -411,11 +418,14 @@ void MainWindow::updateWidgets()
         btn->setChecked(btn->layout() == project->layout());
     }
 
+    ui->printersCombo->setCurrentPrinterProfile(project->printer(), project->printer()->currentProfileIndex());
+
+
     ui->actionPrint->setEnabled(project->pageCount() > 0);
     ui->actionPrintAndClose->setEnabled(ui->actionPrint->isEnabled());
 
-    ui->actionPreviousSheet->setEnabled(ui->preview->currentSheet() > 0);
-    ui->actionNextSheet->setEnabled(ui->preview->currentSheet() < project->previewSheetCount() - 1);
+    ui->actionPreviousSheet->setEnabled(project->currentSheetNum() > 0);
+    ui->actionNextSheet->setEnabled(project->currentSheetNum() < project->previewSheetCount() - 1);
 
     ui->actionSave->setEnabled(project->pageCount() > 0);
     ui->actionSaveAs->setEnabled(ui->actionSave->isEnabled());
@@ -439,14 +449,28 @@ void MainWindow::updateWidgets()
                           ceil(project->sheetCount() / 2.0) :
                           project->sheetCount();
 
-        QString pagesTmpl = (project->pageCount() > 1) ? tr("%1 pages", "Status bar") : tr("%1 page", "Status bar");
-        QString sheetsTmpl = (sheetsCount > 1) ? tr("%1 sheets", "Status bar") : tr("%1 sheet", "Status bar");
-        mStatusBarSheetsLabel.setText(pagesTmpl.arg(project->pageCount()) +
-                                   " ( " + sheetsTmpl.arg(sheetsCount) + " )");
 
+        QString pagesStr;
+        if (project->currentPage())
+        {
+            pagesStr = tr("Page %1 of %2", "Status bar")
+                    .arg(project->currentPageNum() + 1)
+                    .arg(project->pageCount());
+        }
+        else
+        {
+            pagesStr = ((project->pageCount() > 1) ? tr("%1 pages", "Status bar") : tr("%1 page", "Status bar"))
+                    .arg(project->pageCount());
+        }
+
+        QString sheetsStr = ((sheetsCount > 1) ? tr("%1 sheets", "Status bar") : tr("%1 sheet", "Status bar"))
+                    .arg(sheetsCount);
+
+        mStatusBarSheetsLabel.setText(pagesStr + " ( " + sheetsStr + " )");
         mStatusBarCurrentSheetLabel.setText(tr("Sheet %1 of %2", "Status bar")
-                                .arg(ui->preview->currentSheet() + 1)
+                                .arg(project->currentSheetNum() + 1)
                                 .arg(project->previewSheetCount()));
+
     }
     else
     {
@@ -467,7 +491,8 @@ void MainWindow::showPrinterSettingsDialog()
     if (printer)
     {
         PrinterSettings *dialog = PrinterSettings::execute(printer);
-        connect(dialog, SIGNAL(accepted()), this, SLOT(applyPrinterSettings()));
+        connect(dialog, SIGNAL(accepted()),
+                this, SLOT(applyPrinterSettings()));
     }
 }
 
@@ -479,7 +504,7 @@ void MainWindow::applyPrinterSettings()
 {
     project->printer()->saveSettings();
     fillPrintersCombo();
-    switchPrinterProfile();
+    project->update();
 }
 
 
@@ -506,25 +531,6 @@ void MainWindow::switchPrinterProfile()
 }
 
 
-/************************************************
-
- ************************************************/
-void MainWindow::switchToJob(const Job &job)
-{
-    ProjectPage *page = job.firstVisiblePage();
-    for (int i=0; i<project->previewSheetCount(); ++i)
-    {
-        const Sheet *sheet = project->previewSheet(i);
-
-        if (sheet->indexOfPage(page) > -1)
-        {
-            ui->preview->setCurrentSheet(i);
-            return;
-        }
-    }
-}
-
-
 /************************************************
  *
  ************************************************/
@@ -546,7 +552,7 @@ QMessageBox *MainWindow::showPrintDialog(const QString &text)
 /************************************************
 
  ************************************************/
-bool MainWindow::print(uint count)
+bool MainWindow::print(uint count, bool collate)
 {
     struct Keeper
     {
@@ -564,6 +570,8 @@ bool MainWindow::print(uint count)
     if (!project->sheetCount())
         return false;
 
+    saveAuto();
+
     bool res = true;
     bool showDialog = project->printer()->isShowProgressDialog();
     QMessageBox *infoDialog = 0;
@@ -638,7 +646,7 @@ bool MainWindow::print(uint count)
              }
 
 
-             res = project->printer()->print(keeper.sheets_1, "", false, count);
+             res = project->printer()->print(keeper.sheets_1, "", false, count, collate);
              if (!res)
              {
                  delete(infoDialog);
@@ -687,7 +695,7 @@ bool MainWindow::print(uint count)
              if (showDialog)
                 infoDialog = showPrintDialog(tr("Print the even pages on %1.").arg(project->printer()->name()));
 
-             res = project->printer()->print(keeper.sheets_2, "", false, count);
+             res = project->printer()->print(keeper.sheets_2, "", false, count, collate);
              if (!res)
              {
                  delete(infoDialog);
@@ -721,7 +729,7 @@ bool MainWindow::print(uint count)
             }
         }
 
-        res = project->printer()->print(keeper.sheets_1, "", project->doubleSided(), count);
+        res = project->printer()->print(keeper.sheets_1, "", project->doubleSided(), count, collate);
         if (!res)
         {
             delete(infoDialog);
@@ -741,9 +749,9 @@ bool MainWindow::print(uint count)
 /************************************************
 
  ************************************************/
-void MainWindow::printAndClose(uint count)
+void MainWindow::printAndClose(uint count, bool collate)
 {
-    if (print(count))
+    if (print(count, collate))
         QTimer::singleShot(200, this, SLOT(close()));
 }
 
@@ -756,7 +764,7 @@ void MainWindow::printWithOptions()
     PrintDialog dialog;
     if (dialog.exec())
     {
-        print(dialog.copies());
+        print(dialog.copies(), dialog.collate());
     }
 }
 
@@ -797,147 +805,11 @@ void MainWindow::updateProgressBar(int value, int all)
 /************************************************
  *
  * ***********************************************/
-void MainWindow::showPreviewContextMenu(int pageNum)
+void MainWindow::showPreviewContextMenu(Sheet*, ProjectPage *page)
 {
-    int sheetNum = ui->preview->currentSheet();
-    Sheet *sheet = 0;
-    ProjectPage *page = 0;
-    Job job;
-
-    if (sheetNum > -1)
-    {
-        sheet = project->previewSheet(sheetNum);
-        page = (pageNum < 0) ? 0 : sheet->page(pageNum);
-    }
-
-    if (page)
-    {
-        int n = project->jobs()->indexOfProjectPage(page);
-        if (n<0)
-            return;
-
-        job = project->jobs()->at(n);
-    }
-
-    QMenu *menu = new QMenu(this);
-
-    // New subbooklet ................................
-    if (page && (page != project->page(0)))
-    {
-        if (!page->isStartSubBooklet())
-        {
-            PageAction *act = new PageAction(tr("Start new booklet from this page"), sheet, page, menu);
-            connect(act, SIGNAL(triggered()),
-                    this, SLOT(startBooklet()));
-            menu->addAction(act);
-        }
-        else
-        {
-            PageAction *act = new PageAction(tr("Don't start new booklet from this page"), sheet, page, menu);
-            connect(act, SIGNAL(triggered()),
-                    this, SLOT(dontStartBooklet()));
-            menu->addAction(act);
-        }
-
-        menu->addSeparator();
-    }
-
-    // New subbooklet ................................
-
-    // Rotation ......................................
-    if (page)
-    {
-        PageAction *act;
-
-        act = new PageAction(Icon::icon(Icon::RotateLeft), tr("Rotate page to the left"), sheet, page, menu);
-        menu->addAction(act);
-        connect(act, SIGNAL(triggered()),
-                this, SLOT(rotatePageLeft()));
-
-        act = new PageAction(Icon::icon(Icon::RotateRight), tr("Rotate page to the right"), sheet, page, menu);
-        menu->addAction(act);
-        connect(act, SIGNAL(triggered()),
-                this, SLOT(rotatePageRight()));
-    }
-    // Rotation ......................................
-
-
-    // Blank page ....................................
-    if (page)
-    {
-        PageAction *act;
-        act = new PageAction(tr("Insert blank page before this page"), sheet, page, menu);
-        menu->addAction(act);
-        connect(act, SIGNAL(triggered()),
-                this, SLOT(insertBlankPageBefore()));
-
-        act = new PageAction(tr("Insert blank page after this page"), sheet, page, menu);
-        menu->addAction(act);
-        connect(act, SIGNAL(triggered()),
-                this, SLOT(insertBlankPageAfter()));
-
-    }
-    // ...............................................
-
-    menu->addSeparator();
-
-    // Delete page ...................................
-    if (page)
-    {
-        PageAction *act;
-        act = new PageAction(tr("Delete this page"), sheet, page, menu);
-        connect(act, SIGNAL(triggered()),
-                this, SLOT(deletePage()));
-        menu->addAction(act);
-
-        int n = job.indexOfPage(page);
-        bool hasVisible = false;
-        for (int p=n+1; p<job.pageCount(); ++p)
-        {
-            if (job.page(p)->visible())
-            {
-                hasVisible = true;
-                break;
-            }
-        }
-        if (hasVisible)
-        {
-            act = new PageAction(tr("Delete pages until the end of the job."), sheet, page, menu);
-            connect(act, SIGNAL(triggered()),
-                    this, SLOT(deletePagesEnd()));
-            menu->addAction(act);
-        }
-    }
-    // ...............................................
-
-    // Undo delete ...................................
-    QMenu *undelMenu = menu->addMenu(tr("Undo delete"));
-    undelMenu->setEnabled(false);
-
-    for(int j=0; j<project->jobs()->count(); ++j)
-    {
-        Job job = project->jobs()->at(j);
-        QMenu *jm = undelMenu->addMenu(QString("%1 %2").arg(j+1).arg(job.title()));
-
-        for(int p=0; p<job.pageCount(); ++p)
-        {
-            ProjectPage *page = job.page(p);
-            if (!page->visible())
-            {
-                PageAction *act;
-                act = new PageAction(tr("Page %1", "'Undo deletion' menu item").arg(p+1), 0, page, menu);
-                connect(act, SIGNAL(triggered()),
-                        this, SLOT(undoDeletePage()));
-
-                jm->addAction(act);
-            }
-        }
-        jm->setEnabled(!jm->isEmpty());
-        undelMenu->setEnabled(undelMenu->isEnabled() || jm->isEnabled());
-    }
-    // ...............................................
-
-    menu->popup(QCursor::pos());
+    QMenu menu;
+    fillPageEditMenu(page, &menu);
+    menu.exec(QCursor::pos());
 }
 
 
@@ -946,42 +818,208 @@ void MainWindow::showPreviewContextMenu(int pageNum)
  ************************************************/
 void MainWindow::showJobViewContextMenu(Job job)
 {
-    QMenu *menu = new QMenu(this);
+    QMenu menu;
+    fillJobEditMenu(job, &menu);
+    menu.exec(QCursor::pos());
+}
 
+
+/************************************************
+ *
+ ************************************************/
+void MainWindow::showEditPageMainMenu()
+{
+    ui->menuEditPage->clear();
+    fillPageEditMenu(project->currentPage(), ui->menuEditPage);
+}
+
+
+/************************************************
+ *
+ ************************************************/
+void MainWindow::showEditJobMainMenu()
+{
+    ProjectPage *page = project->currentPage();
+    Job job;
+    if (page)
+    {
+        int n = project->jobs()->indexOfProjectPage(page);
+        if (n >= 0)
+            job = project->jobs()->at(n);
+    }
+
+    ui->menuEditJob->clear();
+    fillJobEditMenu(job, ui->menuEditJob);
+}
+
+
+/************************************************
+ *
+ ************************************************/
+void MainWindow::fillPageEditMenu(ProjectPage *page, QMenu *menu)
+{
+    PageAction *act;
+
+    // New subbooklet ................................
+    act = new PageAction(tr("Start new booklet from this page"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(startBooklet()));
+    act->setEnabled(page && page != project->page(0));
+    act->setVisible(page && !page->isManualStartSubBooklet());
+    menu->addAction(act);
+
+
+    act = new PageAction(tr("Don't start new booklet from this page"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(dontStartBooklet()));
+    act->setEnabled(page && page != project->page(0));
+    act->setVisible(page && page->isManualStartSubBooklet());
+    menu->addAction(act);
+    // New subbooklet ................................
+
+
+    menu->addSeparator();
+
+
+    // Rotation ......................................
+    act = new PageAction(tr("Rotate page to the left"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(rotatePageLeft()));
+    act->setEnabled(page);
+    menu->addAction(act);
+
+    act = new PageAction(tr("Rotate page to the right"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(rotatePageRight()));
+    act->setEnabled(page);
+    menu->addAction(act);
+    // Rotation ......................................
+
+
+    menu->addSeparator();
+
+
+    // Blank page ....................................
+    act = new PageAction(tr("Insert blank page before this page"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(insertBlankPageBefore()));
+    act->setEnabled(page);
+    menu->addAction(act);
+
+    act = new PageAction(tr("Insert blank page after this page"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(insertBlankPageAfter()));
+    act->setEnabled(page);
+    menu->addAction(act);
+    // Blank page ....................................
+
+
+    menu->addSeparator();
+
+
+    // Delete page ...................................
+    act = new PageAction(tr("Delete this page"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(deletePage()));
+    act->setEnabled(page);
+    menu->addAction(act);
+
+
+    act = new PageAction(tr("Delete pages until the end of the job"), page, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(deletePagesEnd()));
+    act->setEnabled(page);
+    menu->addAction(act);
+    // Delete page ...................................
+
+    // Undo delete ...................................
+    QMenu *undelMenu = menu->addMenu(tr("Undo delete"));
+    undelMenu->setEnabled(false);
+
+
+    for(int j=0; j<project->jobs()->count(); ++j)
+    {
+        Job job = project->jobs()->at(j);
+
+        for(int p=0; p<job.pageCount(); ++p)
+        {
+            ProjectPage *page = job.page(p);
+
+            if (page->visible())
+                continue;
+
+            act = new PageAction(tr("%1 %2: Page %3",
+                                    "'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job")
+                                 .arg(j+1).arg(job.title()).arg(p+1),
+                                 page, undelMenu);
+
+            connect(act, SIGNAL(triggered()), this, SLOT(undoDeletePage()));
+            undelMenu->addAction(act);
+        }
+
+        undelMenu->setStyleSheet("* {menu-scrollable: 1 }");
+        undelMenu->setEnabled(undelMenu->actions().count() > 0);
+    }
+    // Undo delete ...................................
+}
+
+
+/************************************************
+ *
+ * ***********************************************/
+void MainWindow::fillJobEditMenu(const Job job, QMenu *menu)
+{
     JobAction *act;
 
     act = new JobAction(tr("Rename job"), job, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(renameJob()));
+    act->setEnabled(job.pageCount());
     menu->addAction(act);
-    connect(act, SIGNAL(triggered()),
-            this, SLOT(renameJob()));
 
 
     act = new JobAction(Icon::icon(Icon::RotateLeft), tr("Rotate job to the left"), job, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(rotateJobLeft()));
+    act->setEnabled(job.pageCount());
     menu->addAction(act);
-    connect(act, SIGNAL(triggered()),
-            this, SLOT(rotateJobLeft()));
+
 
     act = new JobAction(Icon::icon(Icon::RotateRight), tr("Rotate job to the right"), job, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(rotateJobRight()));
+    act->setEnabled(job.pageCount());
     menu->addAction(act);
-    connect(act, SIGNAL(triggered()),
-            this, SLOT(rotateJobRight()));
 
 
     menu->addSeparator();
 
+
     act = new JobAction(tr("Clone job..."), job, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(cloneJob()));
+    act->setEnabled(job.pageCount());
     menu->addAction(act);
-    connect(act, SIGNAL(triggered()),
-            this, SLOT(cloneJob()));
+
 
     menu->addSeparator();
 
-    act = new JobAction(tr("Delete job"), job, menu);
-    menu->addAction(act);
-    connect(act, SIGNAL(triggered()),
-            this, SLOT(deleteJob()));
 
-    menu->popup(QCursor::pos());
+
+    // Undo delete ...................................
+    QMenu *undelMenu = menu->addMenu(tr("Undo delete page"));
+    undelMenu->setEnabled(false);
+
+    for(int p=0; p<job.pageCount(); ++p)
+    {
+        ProjectPage *page = job.page(p);
+        if (page->visible())
+            continue;
+
+        PageAction *act;
+        act = new PageAction(tr("Page %1", "'Undo deletion' menu item").arg(p+1), page, undelMenu);
+        connect(act, SIGNAL(triggered()), this, SLOT(undoDeletePage()));
+
+        undelMenu->addAction(act);
+    }
+    undelMenu->setEnabled(undelMenu->isEnabled() || !undelMenu->isEmpty());
+    // ...............................................
+
+
+    menu->addSeparator();
+
+    act = new JobAction(tr("Delete current job"), job, menu);
+    connect(act, SIGNAL(triggered()), this, SLOT(deleteJob()));
+    act->setEnabled(job.pageCount());
+    menu->addAction(act);
 }
 
 
@@ -994,19 +1032,7 @@ void MainWindow::deletePage()
     if (!act || !act->page())
         return;
 
-    if (act->page()->isBlankPage())
-    {
-        int n = project->jobs()->indexOfProjectPage(act->page());
-        if (n<0)
-            return;
-
-        project->jobs()->value(n).removePage(act->page());
-    }
-    else
-    {
-        act->page()->hide();
-    }
-    project->update();
+    project->deletePage(act->page());
 }
 
 
@@ -1019,11 +1045,7 @@ void MainWindow::undoDeletePage()
     if (!act || !act->page())
         return;
 
-    if (!act->page()->visible())
-    {
-        act->page()->show();
-        project->update();
-    }
+    project->undoDeletePage(act->page());
 }
 
 
@@ -1036,24 +1058,7 @@ void MainWindow::deletePagesEnd()
     if (!act || !act->page())
         return;
 
-    int n = project->jobs()->indexOfProjectPage(act->page());
-    if (n<0)
-        return;
-
-    Job job = project->jobs()->value(n);
-
-    QList<ProjectPage*> deleted;
-    for (int p=job.pageCount()-1; p>=job.indexOfPage(act->page()); --p)
-    {
-        ProjectPage *page = job.page(p);
-
-        if (page->isBlankPage())
-            deleted << page;
-        else
-            page->hide();
-    }
-
-    job.removePages(deleted);
+    project->deletePagesEnd(act->page());
 }
 
 
@@ -1066,13 +1071,7 @@ void MainWindow::insertBlankPageBefore()
     if (!act || !act->page())
         return;
 
-    int j = project->jobs()->indexOfProjectPage(act->page());
-    if (j<0)
-        return;
-
-    Job job = project->jobs()->value(j);
-    int n = job.indexOfPage(act->page());
-    job.insertBlankPage(n);
+    project->insertBlankPageBefore(act->page());
 }
 
 
@@ -1085,13 +1084,7 @@ void MainWindow::insertBlankPageAfter()
     if (!act || !act->page())
         return;
 
-    int j = project->jobs()->indexOfProjectPage(act->page());
-    if (j<0)
-        return;
-
-    Job job = project->jobs()->value(j);
-    int n = job.indexOfPage(act->page());
-    job.insertBlankPage(n+1);
+    project->insertBlankPageAfter(act->page());
 }
 
 
@@ -1163,8 +1156,7 @@ void MainWindow::rotatePageLeft()
     if (!act || !act->page())
         return;
 
-    ProjectPage *page = act->page();
-    page->setManualRotation(page->manualRotation() - Rotate90);
+    act->page()->setManualRotation(act->page()->manualRotation() - Rotate90);
     project->update();
 }
 
@@ -1178,8 +1170,7 @@ void MainWindow::rotatePageRight()
     if (!act || !act->page())
         return;
 
-    ProjectPage *page = act->page();
-    page->setManualRotation(page->manualRotation() + Rotate90);
+    act->page()->setManualRotation(act->page()->manualRotation() + Rotate90);
     project->update();
 }
 
@@ -1193,12 +1184,12 @@ void MainWindow::startBooklet()
     if (!act || !act->page())
         return;
 
-    act->page()->setStartSubBooklet(true);
+    act->page()->setManualStartSubBooklet(true);
     project->update();
 
     int sheetNum = project->previewSheets().indexOfPage(act->page());
     if (sheetNum > -1)
-        ui->preview->setCurrentSheet(sheetNum);
+        project->setCurrentSheet(sheetNum);
 }
 
 
@@ -1210,13 +1201,13 @@ void MainWindow::dontStartBooklet()
     PageAction *act = qobject_cast<PageAction*>(sender());
     if (!act || !act->page())
         return;
-    qDebug() << "";
-    act->page()->setStartSubBooklet(false);
+
+    act->page()->setManualStartSubBooklet(false);
     project->update();
 
     int sheetNum = project->previewSheets().indexOfPage(act->page());
     if (sheetNum > -1)
-        ui->preview->setCurrentSheet(sheetNum);
+        project->setCurrentSheet(sheetNum);
 }
 
 
@@ -1267,6 +1258,7 @@ void MainWindow::deleteJob()
         project->removeJob(index);
 
     ui->jobsView->updateItems();
+    ui->subBookletView->updateItems();
 }
 
 
@@ -1294,11 +1286,14 @@ void MainWindow::saveAs(const QString &fileName)
 
         if (file.isEmpty())
             return;
+
+        if (QFileInfo(file).suffix().toLower() != "boo")
+            file += ".boo";
     }
 
     mSaveFile = file;
     settings->setValue(Settings::SaveDir, QFileInfo(file).path());
-
+    addToRecentFiles(file);
 
     try
     {
@@ -1317,10 +1312,24 @@ void MainWindow::saveAs(const QString &fileName)
  * ***********************************************/
 void MainWindow::exportAs()
 {
-    Printer *prevPrinter = project->printer();
-    project->setPrinterProfile(mExportPrinter, mExportPrinter->currentProfile(), false);
-    print();
-    project->setPrinterProfile(prevPrinter, prevPrinter->currentProfile(), false);
+    QString fileName = settings->value(Settings::ExportPDF_FileName).toString();
+
+    ExportToPdf dialog;
+    dialog.setOutFileName(fileName);
+    dialog.setMetaInfo(project->metaData());
+
+    dialog.setModal(true);
+    if (!dialog.exec())
+        return;
+
+    fileName = dialog.outFileName();
+    settings->setValue(Settings::ExportPDF_FileName, fileName);
+    fileName = expandHomeDir(fileName);
+
+    project->setMetadata(dialog.metaInfo());
+
+    QList<Sheet*> sheets = project->selectSheets(Project::AllPages, Project::ForwardOrder);
+    project->writeDocument(sheets, fileName);
 }
 
 
@@ -1347,3 +1356,91 @@ void MainWindow::load()
         project->error(err);
     }
 }
+
+/************************************************
+ *
+ ************************************************/
+void MainWindow::fillRecentFiles()
+{
+    ui->menuRecentFiles->clear();
+
+    QStringList recentFiles = settings->value(Settings::RecentFiles).toStringList();
+    foreach (QString file, recentFiles)
+    {
+        QAction *act = new QAction(ui->menuRecentFiles);
+        act->setText(QFileInfo(file).fileName());
+        act->setData(file);
+        ui->menuRecentFiles->addAction(act);
+        connect(act, SIGNAL(triggered()),
+                this, SLOT(loadAuto()));
+    }
+
+    ui->menuRecentFiles->setEnabled(ui->menuRecentFiles->actions().count());
+}
+
+
+/************************************************
+
+ ************************************************/
+void MainWindow::addToRecentFiles(const QString &file)
+{
+    QStringList recentFiles = settings->value(Settings::RecentFiles).toStringList();
+    recentFiles.removeAll(file);
+    recentFiles << file;
+
+    while (recentFiles.size() > 20)
+        recentFiles.removeFirst();
+
+    settings->setValue(Settings::RecentFiles, recentFiles);
+}
+
+/************************************************
+
+ ************************************************/
+void MainWindow::saveAuto()
+{
+    if (!settings->value(Settings::AutoSave).toBool())
+            return;
+
+    QString dir = settings->value(Settings::AutoSaveDir).toString();
+    if (dir.startsWith("~"))
+        dir.replace(0, 1, QDir::homePath());
+
+    qDebug() << dir;
+
+    if (!QDir().mkpath(dir))
+    {
+        qWarning() << QString("Can't create autosave directory '%1'").arg(dir);
+        QMessageBox::warning(this, tr("Auto saving"), tr("I can't create directory \"%1\"")
+                             .arg(dir));
+        return;
+    }
+
+    QString file = QString("[%1]-%2.boo")
+            .arg(QDateTime::currentDateTime().toString("yyyy.MM.dd-hh:mm:ss"))
+            .arg(safeFileName(safeFileName(project->jobs()->first().title(true))));
+
+    file = dir + "/" + file;
+    addToRecentFiles(file);
+    project->save(file);
+}
+
+
+/************************************************
+ *
+ ************************************************/
+void MainWindow::loadAuto()
+{
+    QAction *act = qobject_cast<QAction*>(sender());
+    if (!act)
+        return;
+
+    try
+    {
+        project->load(act->data().toString());
+    }
+    catch (QString &err)
+    {
+        project->error(err);
+    }
+}
