@@ -38,6 +38,7 @@ class Project;
 class Printer;
 class QMessageBox;
 class ExportToPDFPrinter;
+class Sheet;
 
 namespace Ui {
 class MainWindow;
@@ -55,14 +56,11 @@ private slots:
     void switchLayout();
     void switchPrinterProfile();
 
-    void switchToJob(const Job &job);
-
-    bool print(uint count = 1);
-    void printAndClose(uint count = 1);
+    bool print(uint count = 1, bool collate = true);
+    void printAndClose(uint count = 1, bool collate = true);
     void printWithOptions();
 
     void updateWidgets();
-
     void showPrinterSettingsDialog();
     void applyPrinterSettings();
 
@@ -70,14 +68,15 @@ private slots:
 
     void updateProgressBar(int value, int all);
 
-    void showPreviewContextMenu(int pageNum);
+    void showPreviewContextMenu(Sheet *sheet, ProjectPage *page);
     void showJobViewContextMenu(Job job);
+    void showEditPageMainMenu();
+    void showEditJobMainMenu();
     void deletePage();
     void undoDeletePage();
     void deletePagesEnd();
     void insertBlankPageBefore();
     void insertBlankPageAfter();
-
     void cloneJob();
     void deleteJob();
     void renameJob();
@@ -97,6 +96,9 @@ private slots:
     void exportAs();
     void load();
 
+    void fillRecentFiles();
+    void loadAuto();
+
 protected:
     void closeEvent(QCloseEvent *event);
     void dragEnterEvent(QDragEnterEvent *event);
@@ -112,7 +114,6 @@ private:
 
     QProgressBar mProgressBar;
     QString      mSaveFile;
-    ExportToPDFPrinter *mExportPrinter;
 
     void fillPrintersCombo();
     void initActions();
@@ -122,6 +123,11 @@ private:
     void saveSettings();
 
     QMessageBox *showPrintDialog(const QString &text);
+    void saveAuto();
+
+    void addToRecentFiles(const QString &file);
+    void fillPageEditMenu(ProjectPage *page, QMenu *menu);
+    void fillJobEditMenu(const Job job, QMenu *menu);
 };
 
 #endif // MAINWINDOW_H
