@@ -27,10 +27,14 @@
 #include "settings.h"
 #include <QDir>
 #include <QDebug>
+#include <QStandardPaths>
+
 
 #define MAINWINDOW_GROUP "MainWindow"
-#define PROJECT_GROUP "Project"
-#define PRINTERS_GROUP "Printer"
+#define PROJECT_GROUP    "Project"
+#define PRINTERS_GROUP   "Printer"
+
+
 
 QString Settings::mFileName;
 
@@ -105,8 +109,18 @@ QString Settings::keyToString(Settings::Key key) const
     case SubBookletsEnabled:            return "Project/SubBookletsEnable";
     case SubBookletSize:                return "Project/SubBookletSize";
 
+    case AllowNegativeMargins:          return "Project/AllowNegativeMargins";
+    case AutoSave:                      return "Project/AutoSave";
+    case AutoSaveDir:                   return "Project/AutoSaveDir";
+    case RecentFiles:                   return "Project/RecentFiles";
+
+    // Preferences **************************
+    case Preferences_Geometry:          return "Preferences/Geometry";
+
     // Printer ******************************
     case Printer_CurrentProfile:        return "CurrentProfile";
+    case Printer_CopiesNum:             return "Printer/CopiesNum";
+    case Printer_CollateCopies:         return "Printer/CollateCopies";
 
     // PrinterProfile ***********************
     case PrinterProfile_Name:           return "Name";
@@ -119,7 +133,8 @@ QString Settings::keyToString(Settings::Key key) const
     case PrinterProfile_TopMargin:      return "TopMargin";
     case PrinterProfile_BottomMargin:   return "BottomMargin";
     case PrinterProfile_InternalMargin: return "InternalMargin";
-
+    case PrinterProfile_ColorMode:      return "ColorMode";
+    case PrinterProfile_FlipType:       return "FlipType";
 
     // PrinterSettingsDialog ****************
     case PrinterSettingsDialog_Geometry:return "PrinterSettingsDialog/Geometry";
@@ -127,6 +142,9 @@ QString Settings::keyToString(Settings::Key key) const
     // MainWindow **************************
     case MainWindow_Geometry:           return "MainWindow/Geometry";
     case MainWindow_State:              return "MainWindow/State";
+    case MainWindow_SplitterPos:        return "MainWindow/SplitterPos";
+    case MainWindow_PageListIconSize:   return "MainWindow/PageListIconSize";
+    case MainWindow_PageListTab:        return "MainWindow/PageListTab";
 
     // PrinterDialog ************************
     case PrinterDialog_Geometry:        return "PrinterDialog/Geometry";
@@ -152,6 +170,16 @@ void Settings::init()
     setDefaultValue(SaveDir, QDir::homePath());
     setDefaultValue(SubBookletsEnabled, true);
     setDefaultValue(SubBookletSize, 20);
+    setDefaultValue(MainWindow_PageListIconSize, 64);
+    setDefaultValue(MainWindow_PageListTab, 0);
+
+    setDefaultValue(AllowNegativeMargins, false);
+    setDefaultValue(AutoSave, false);
+
+    QString dir = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+    dir = shrinkHomeDir(dir);
+    setDefaultValue(AutoSaveDir, QDir(dir).filePath("Boomaga files"));
+
 }
 
 
