@@ -44,11 +44,20 @@ public:
         SaveDir,
         SubBookletsEnabled,
         SubBookletSize,
+        AllowNegativeMargins,
+        AutoSave,
+        AutoSaveDir,
+        RecentFiles,
+
+        // Preferences **************************
+        Preferences_Geometry,
 
         // Printer ******************************
         Printer_CurrentProfile,
+        Printer_CopiesNum,
+        Printer_CollateCopies,
 
-        // PrinterProfile ******************************
+        // PrinterProfile ***********************
         PrinterProfile_Name,
         PrinterProfile_DuplexType,
         PrinterProfile_DrawBorder,
@@ -59,6 +68,8 @@ public:
         PrinterProfile_TopMargin,
         PrinterProfile_BottomMargin,
         PrinterProfile_InternalMargin,
+        PrinterProfile_ColorMode,
+        PrinterProfile_FlipType,
 
         // PrinterSettingsDialog ****************
         PrinterSettingsDialog_Geometry,
@@ -66,6 +77,9 @@ public:
         // MainWindow ***************************
         MainWindow_Geometry,
         MainWindow_State,
+        MainWindow_SplitterPos,
+        MainWindow_PageListIconSize,
+        MainWindow_PageListTab,
 
         // PrinterDialog ************************
         PrinterDialog_Geometry,
