@@ -32,6 +32,7 @@
 #include <QString>
 #include <QStringList>
 #include <QList>
+#include <QTemporaryFile>
 
 #define protected public
 #include "../kernel/layout.h"
@@ -39,7 +40,8 @@
 #include "../kernel/sheet.h"
 #include "../kernel/projectfile.h"
 #include "../boomagatypes.h"
-
+#include "../kernel/projectpage.h"
+#include "../settings.h"
 
 #define COMPARE(actual, expected) \
     do {\
@@ -57,9 +59,18 @@ do {\
 /************************************************
  *
  * ***********************************************/
-TestBoomaga::TestBoomaga(QObject *parent)
+TestBoomaga::TestBoomaga(QObject *parent):
+    QObject(parent)
 {
+}
 
+void TestBoomaga::initTestCase()
+{
+    QTemporaryFile *tmpFile = new QTemporaryFile(this);
+    if (!tmpFile->open())
+        QFAIL("Can't create temporary file");
+
+    Settings::setFileName(tmpFile->fileName());
 }
 
 
@@ -730,91 +741,92 @@ void TestBoomaga::test_PagePosition_data()
      *  +---+
      ********************************************/
     //          Layout Rotation     Expected
-    QTest::newRow("1up; 0"   )  << "+---+"
-                                   "| 0 |"
-                                   "+---+";
-    QTest::newRow("1up; 90"  )  << "+---+"
-                                   "| 0 |"
-                                   "+---+";
+    QTest::newRow("1up; 0"   )     << "+---+"
+                                      "| 0 |"
+                                      "+---+";
+
+    QTest::newRow("1up; 90"  )     << "+---+"
+                                      "| 0 |"
+                                      "+---+";
 
 
-    //          Layout Rotation    Expected      On screen
-    QTest::newRow("2up; 90"  )  << "+---+"    // +------+
-                                   "| 1 |"    // | 0  1 | Rotate
-                                   "| 0 |"    // +------+
-                                   "+---+";
+    //          Layout Rotation    Expected          On screen
+    QTest::newRow("2up; 90"  )     << "+---+"     // +------+
+                                      "| 1 |"     // | 0  1 | Rotate
+                                      "| 0 |"     // +------+
+                                      "+---+";
 
-    QTest::newRow("2up; 0"   )  << "+---+"    // +---+
-                                   "| 0 |"    // | 0 | No rotate
-                                   "| 1 |"    // | 1 |
-                                   "+---+";   // +---+
+    QTest::newRow("2up; 0"   )     << "+---+"     // +---+
+                                      "| 0 |"     // | 0 | No rotate
+                                      "| 1 |"     // | 1 |
+                                      "+---+";    // +---+
 
 
-    //          Layout Rotation        Expected       On screen
-    QTest::newRow("4up_Horiz; 0")  << "+-----+"    // +-----+
-                                      "| 0 1 |"    // | 0 1 | No rotate
-                                      "| 2 3 |"    // | 2 3 |
-                                      "+-----+";   // +-----+
+    //          Layout Rotation        Expected      On screen
+    QTest::newRow("4up_Horiz; 0")  << "+-----+"   // +-----+
+                                      "| 0 1 |"   // | 0 1 | No rotate
+                                      "| 2 3 |"   // | 2 3 |
+                                      "+-----+";  // +-----+
 
-    QTest::newRow("4up_Horiz; 90") << "+-----+"    // +-----+
-                                      "| 1 3 |"    // | 0 1 | Rotate
-                                      "| 0 2 |"    // | 2 3 |
-                                      "+-----+";   // +-----+
+    QTest::newRow("4up_Horiz; 90") << "+-----+"   // +-----+
+                                      "| 1 3 |"   // | 0 1 | Rotate
+                                      "| 0 2 |"   // | 2 3 |
+                                      "+-----+";  // +-----+
 
 
-    //          Layout Rotation        Expected       On screen
-    QTest::newRow("4up_Vert;  0")  << "+-----+"    // +-----+
-                                      "| 0 2 |"    // | 0 2 | No rotate
-                                      "| 1 3 |"    // | 1 3 |
-                                      "+-----+";   // +-----+
+    //          Layout Rotation        Expected      On screen
+    QTest::newRow("4up_Vert;  0")  << "+-----+"   // +-----+
+                                      "| 0 2 |"   // | 0 2 | No rotate
+                                      "| 1 3 |"   // | 1 3 |
+                                      "+-----+";  // +-----+
 
-    QTest::newRow("4up_Vert; 90")  << "+-----+"    // +-----+
-                                      "| 2 3 |"    // | 0 2 | Rotate
-                                      "| 0 1 |"    // | 1 3 |
-                                      "+-----+";   // +-----+
+    QTest::newRow("4up_Vert; 90")  << "+-----+"   // +-----+
+                                      "| 2 3 |"   // | 0 2 | Rotate
+                                      "| 0 1 |"   // | 1 3 |
+                                      "+-----+";  // +-----+
 
 
-    //          Layout Rotation        Expected           On screen
-    QTest::newRow("8up_Horiz; 90") << "+-----+"        // +---------+
-                                      "| 3 7 |"        // | 0 1 2 3 | Rotate
-                                      "| 2 6 |"        // | 4 5 6 7 |
-                                      "| 1 5 |"        // +---------+
+    //          Layout Rotation        Expected      On screen
+    QTest::newRow("8up_Horiz; 90") << "+-----+"   // +---------+
+                                      "| 3 7 |"   // | 0 1 2 3 | Rotate
+                                      "| 2 6 |"   // | 4 5 6 7 |
+                                      "| 1 5 |"   // +---------+
                                       "| 0 4 |"
                                       "+-----+";
 
-    QTest::newRow("8up_Horiz;  0") << "+-----+"        // +-----+
-                                      "| 0 1 |"        // | 0 1 | No rotate
-                                      "| 2 3 |"        // | 2 3 |
-                                      "| 4 5 |"        // | 4 5 |
-                                      "| 6 7 |"        // | 6 7 |
-                                      "+-----+";       // +-----+
+    QTest::newRow("8up_Horiz;  0") << "+-----+"   // +-----+
+                                      "| 0 1 |"   // | 0 1 | No rotate
+                                      "| 2 3 |"   // | 2 3 |
+                                      "| 4 5 |"   // | 4 5 |
+                                      "| 6 7 |"   // | 6 7 |
+                                      "+-----+";  // +-----+
 
 
-    //          Layout Rotation        Expected           On screen
-    QTest::newRow("8up_Vert;  90") << "+-----+"        // +---------+
-                                      "| 6 7 |"        // | 0 2 4 6 | Rotate
-                                      "| 4 5 |"        // | 1 3 5 7 |
-                                      "| 2 3 |"        // +---------+
+    //          Layout Rotation        Expected      On screen
+    QTest::newRow("8up_Vert;  90") << "+-----+"   // +---------+
+                                      "| 6 7 |"   // | 0 2 4 6 | Rotate
+                                      "| 4 5 |"   // | 1 3 5 7 |
+                                      "| 2 3 |"   // +---------+
                                       "| 0 1 |"
                                       "+-----+";
 
-    QTest::newRow("8up_Vert;   0") << "+-----+"        // +-----+
-                                      "| 0 4 |"        // | 0 4 | No rotate
-                                      "| 1 5 |"        // | 1 5 |
-                                      "| 2 6 |"        // | 2 6 |
-                                      "| 3 7 |"        // | 3 7 |
-                                      "+-----+";       // +-----+
+    QTest::newRow("8up_Vert;   0") << "+-----+"   // +-----+
+                                      "| 0 4 |"   // | 0 4 | No rotate
+                                      "| 1 5 |"   // | 1 5 |
+                                      "| 2 6 |"   // | 2 6 |
+                                      "| 3 7 |"   // | 3 7 |
+                                      "+-----+";  // +-----+
 
-    //          Layout Rotation         Expected      On screen
-    QTest::newRow("booklet; 90" )  << "+---+"    // +------+
-                                      "| 1 |"    // | 0  1 | Rotate
-                                      "| 0 |"    // +------+
+    //          Layout Rotation        Expected      On screen
+    QTest::newRow("booklet; 90" )  << "+---+"     // +------+
+                                      "| 1 |"     // | 0  1 | Rotate
+                                      "| 0 |"     // +------+
                                       "+---+";
 
-    QTest::newRow("booklet; 0"  )  << "+---+"    // +---+
-                                      "| 0 |"    // | 0 | No rotate
-                                      "| 1 |"    // | 1 |
-                                      "+---+";   // +---+
+    QTest::newRow("booklet; 0"  )  << "+---+"     // +---+
+                                      "| 0 |"     // | 0 | No rotate
+                                      "| 1 |"     // | 1 |
+                                      "+---+";    // +---+
 }
 
 
@@ -944,58 +956,63 @@ void TestBoomaga::test_ProjectFilePageSpec_data()
 /************************************************
  *
  * ***********************************************/
-void TestBoomaga::test_SheetRotation()
+void TestBoomaga::test_BooklesSplit()
 {
-     QStringList tags = QString(QTest::currentDataTag()).split(" ", QString::SkipEmptyParts);
-     LayoutNUp *layout = createLayout(tags.at(0));
-     DuplexType duplex = (tags.at(1).toUpper() == "AUTO") ?
-                            DuplexAuto :
-                            DuplexManual;
+    settings->setValue(Settings::SubBookletsEnabled, true);
+    settings->setValue(Settings::SubBookletSize, 2);
 
-     Rotation projectRotation = StrToRotation(tags.at(2));
+    QStringList tags = QString(QTest::currentDataTag()).split(":", QString::SkipEmptyParts);
+    QString pageSpec = tags.count() > 2 ? tags.at(2): "";
 
-     QFETCH(QString, rotationsExpected);
+    QList<ProjectPage*> pages;
+    foreach (QString spec, pageSpec.split(" ", QString::SkipEmptyParts))
+    {
+        ProjectPage *page = new ProjectPage();
+        page->setManualStartSubBooklet(spec.contains("M"));
+        //qDebug() << spec << spec.contains("M") << ;
+        pages << page;
+    }
 
-     QStringList expectedSl = rotationsExpected.split(" ", QString::SkipEmptyParts);
-     QStringList resultSl;
-     for (int i=0; i<expectedSl.count(); ++i)
-     {
-         resultSl << QString::number(
-                         (int)layout->calcSheetRotation(i, projectRotation, duplex, true));
-     }
+    LayoutNUp *layout = createLayout(tags.at(0));
+    layout->updatePages(pages);
 
-     QString result = resultSl.join(" ");
-     QString expected = expectedSl.join(" ");
-     QCOMPARE(result, expected);
+    QFETCH(QString, expected);
+    expected = expected.simplified();
+    QString result;
+
+    for(int i=0; i< pages.count(); ++i)
+    {
+        if (pages.at(i)->isStartSubBooklet())
+            result += QString(" %1").arg(i+1);
+    }
+    result = result.simplified();
+
+    QCOMPARE(result, expected);
+
+
+    qDeleteAll(pages);
+    delete layout;
 }
 
-
 /************************************************
  *
  * ***********************************************/
-void TestBoomaga::test_SheetRotation_data()
+void TestBoomaga::test_BooklesSplit_data()
 {
-    QTest::addColumn<QString>("rotationsExpected");
+    QTest::addColumn<QString>("expected");
+    //QTest::newRow("booklet: 4 pps:") << "";
+    QTest::newRow("booklet: 4 pps: 1") << "1";
 
-    //          Layout duplex rotation    results
-    QTest::newRow("1up Manual  0") << " 0 180   0 180";
-    QTest::newRow("1up Manual 90") << "90  90  90  90";
-    QTest::newRow("2up Manual  0") << " 0 180   0 180";
-    QTest::newRow("2up Manual 90") << "90  90  90  90";
-
-
-    QTest::newRow("1up Auto    0") << " 0   0   0   0";
-    QTest::newRow("1up Auto   90") << "90 270  90 270";
-    QTest::newRow("2up Auto    0") << " 0   0   0   0";
-    QTest::newRow("2up Auto   90") << "90 270  90 270";
-
-
-    QTest::newRow("booklet Manual  0") << " 0   0   0   0";
-    QTest::newRow("booklet Manual 90") << "90  90  90  90";
-    QTest::newRow("booklet Auto    0") << " 0 180   0 180";
-    QTest::newRow("booklet Auto   90") << "90 270  90 270";
+    QTest::newRow("booklet: 4 pps: 1 2 3 4 5 6 7") << "1";
+    QTest::newRow("booklet: 4 pps: 1 2 3 4 5 6 7 8") << "1";
+    QTest::newRow("booklet: 4 pps: 1 2 3 4 5 6 7 8   9 10") << "1 9";
+    QTest::newRow("booklet: 4 pps: 1 2 3 4 5 6 7 8   9 10 11 12 13 14 15 16") << "1 9";
+    QTest::newRow("booklet: 4 pps: 1 2 3 4 5 6 7 8   9 10 11 12 13 14 15 16  17") << "1 9 17";
 
+    QTest::newRow("booklet: 4 pps: 1 2M 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18") << "1 2 10 18";
+    QTest::newRow("booklet: 4 pps: 1 2M 3 4 5 6M 7 8 9 10 11 12 13 14 15 16 17 18") << "1 2 6 14";
+    QTest::newRow("booklet: 4 pps: 1 2M 3 4 5 6 7 8 9 10M 11 12 13 14 15 16 17 18") << "1 2 10 18";
 }
 
 
-QTEST_MAIN(TestBoomaga)
+QTEST_GUILESS_MAIN(TestBoomaga)
