@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -41,10 +41,6 @@
         <source>License: %1</source>
         <translation>Licence: %1</translation>
     </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation>Boomaga je vyvíjena &lt;a %1&gt;týmem Boomaga a přispěvateli&lt;/a&gt; on Github.</translation>
-    </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <translation>Pokud byste měli zájem pracovat v naší vývojářské skupině, &lt;a %1&gt;připojte se k nám&lt;/a&gt;.</translation>
@@ -57,6 +53,10 @@
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation>Pokud chcete pomoci s překladem, podívejte se na překladatelský tým na &lt;a %1&gt;Transifexu&lt;/a&gt;.</translation>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation>Boomaga je vyvíjena &lt;a %1&gt;týmem Boomaga a přispěvateli&lt;/a&gt; na GitHub.</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -80,6 +80,26 @@
         <source>Sheets per sub-booklet:</source>
         <translation>Listů na dílčí knížečku</translation>
     </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation>Při tisku vždy automaticky uložit vaše úlohy.</translation>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation>Automaticky uložit nedávná sezení</translation>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation>Povolit záporné okraje stran:</translation>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation>Vybrat adresář pro uložené úlohy.</translation>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation>Adresář pro uložená sezení:</translation>
+    </message>
 </context>
 <context>
     <name>ExportToPdf</name>
@@ -115,10 +135,6 @@
         <source>Title:</source>
         <translation>Název:</translation>
     </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation>Název dokumentu.</translation>
-    </message>
     <message>
         <source>Subject:</source>
         <translation>Předmět:</translation>
@@ -155,10 +171,10 @@ Jste si jistý, že jej chcete přepsat?</translation>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
-        <translation>( %1 stran(y) ) </translation>
+        <source>%1 pages</source>
+        <translation>%1 stran</translation>
     </message>
 </context>
 <context>
@@ -175,10 +191,6 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Help</source>
         <translation>Nápověda</translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation>Volby</translation>
-    </message>
     <message>
         <source>Layout</source>
         <translation>Rozvržení</translation>
@@ -315,10 +327,6 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Insert blank page before this page</source>
         <translation>Vložit prázdnou stranu před tuto stranu</translation>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation>Odstranit strany až po konec úlohy</translation>
-    </message>
     <message>
         <source>Save</source>
         <translation>Uložit</translation>
@@ -416,18 +424,10 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Rotate job to the right</source>
         <translation>Otočit tiskovou úlohu doprava</translation>
     </message>
-    <message>
-        <source>Delete job</source>
-        <translation>Smazat tiskovou úlohu</translation>
-    </message>
     <message>
         <source>Job title:</source>
         <translation>Název tiskové úlohy:</translation>
     </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation>&amp;Vyvést...</translation>
-    </message>
     <message>
         <source>Export the project to PDF</source>
         <translation>Vyvést projekt do PDF</translation>
@@ -460,6 +460,63 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Ctrl+Shift+P</source>
         <translation>Ctrl+Shift+P</translation>
     </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation>Dílčí knížečky</translation>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation>Zpět smazání strany</translation>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation>Strana %1 z %2</translation>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation>Nedávné soubory</translation>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation>&amp;Upravit stranu</translation>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation>Upravit úl&amp;ohu</translation>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation>&amp;Vyvést do PDF...</translation>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation>Odstranit strany až po konec úlohy</translation>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation>Smazat nynější úlohu</translation>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation>Automatické ukládání</translation>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation>Nelze vytvořit adresář &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation>%1 %2: Strana %3</translation>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -471,6 +528,10 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Number of copies:</source>
         <translation>Počet kopií:</translation>
     </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation>Srovnat kopie:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -498,10 +559,6 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Top:</source>
         <translation>Nahoře:</translation>
     </message>
-    <message>
-        <source>Duplex:</source>
-        <translation>Tisk pravá-levá stránka:</translation>
-    </message>
     <message>
         <source>Draw border</source>
         <translation>Kreslit okraj</translation>
@@ -547,6 +604,38 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
         <translation>Profil %1</translation>
     </message>
+    <message>
+        <source>Color mode:</source>
+        <translation>Barevný režim:</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Výchozí</translation>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation>Vynutit odstíny šedi</translation>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation>Vynutit barvu</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Nastavení</translation>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation>Tisknout na obě strany</translation>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation>Převrátit na krátkém okraji</translation>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation>Převrátit na dlouhém okraji</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -559,48 +648,36 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
     </message>
-</context>
-<context>
-    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation>Nelze otevřít soubor &quot;%1&quot; (Žádný takový soubor nebo adresář)</translation>
+        <translation>Nelze otevřít soubor &quot;%1&quot; (žádný takový soubor nebo adresář)</translation>
     </message>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation>Nelze otevřít soubor &quot;%1&quot; (Přístup odepřen)</translation>
+        <translation>Nelze otevřít soubor &quot;%1&quot; (přístup odepřen)</translation>
     </message>
     <message>
         <source>I can&apos;t open file &quot;%1&quot;</source>
         <translation>Nelze otevřít soubor &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Nelze přečíst soubor &quot;%1&quot;, protože buď tento není podporovaným souborovým typem, nebo protože soubor byl poškozen.</translation>
+    </message>
+</context>
+<context>
+    <name>ProjectFile</name>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <translation>Nelze otevřít soubor &quot;%1&quot;</translation>
+    </message>
     <message>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
     </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
-        <translation>Nelze přečíst soubor &quot;%1&quot;, protože buď tento není podporovaným souborovým typem, nebo protože soubor byl poškozen.</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation>Soubor PDF &quot;%1&quot; je poškozen.</translation>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation>Soubor PDF &quot;%1&quot; je zašifrován.</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Nelze otevřít soubor &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>Print to file (PDF)</source>
-        <translation>Tisk do souboru (PDF)</translation>
-    </message>
     <message>
         <source>I can&apos;t read from file &apos;%1&apos;</source>
         <translation>Nelze číst ze souboru &apos;%1&apos;</translation>
@@ -626,6 +703,17 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <translation>~/Nepojmenovaný.pdf</translation>
     </message>
 </context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation>Dílčí knížečka %1</translation>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation>%1 stran</translation>
+    </message>
+</context>
 <context>
     <name>TmpPdfFile</name>
     <message>
