@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -41,10 +41,6 @@
         <source>License: %1</source>
         <translation>Lizenz: %1</translation>
     </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation>Boomaga wird vom &lt;a %1&gt;Boomaga Team und Freiwilligen&lt;/a&gt; auf Github entwickelt.</translation>
-    </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <translation>Wer mit dem Entwickler-Team zusammenarbeiten möchte, bitte &lt;a %1&gt;hier melden&lt;/a&gt;.</translation>
@@ -57,6 +53,10 @@
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation>Wenn Du zur Übersetzung beitragen möchtest, würden wir uns freuen, dich im Übersetzungsteam auf &lt;a %1&gt;Transifex&lt;/a&gt; begrüßen zu dürfen.</translation>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation>Boomaga wird vom &lt;a %1&gt;Boomaga-Team und Beitragenden&lt;/a&gt; auf GitHub entwickelt.</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -80,6 +80,26 @@
         <source>Sheets per sub-booklet:</source>
         <translation>Blätter pro sub-booklet:</translation>
     </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation>Automatisches Speichern Ihrer Aufträge bei jedem Druckvorgang.</translation>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation>Letzte Sitzungen automatisch speichern</translation>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation>Negative Seitenränder erlauben:</translation>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation>Verzeichnis für gespeicherte Aufträge auswählen.</translation>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation>Verzeichnis für gespeicherte Sitzungen:</translation>
+    </message>
 </context>
 <context>
     <name>ExportToPdf</name>
@@ -115,10 +135,6 @@
         <source>Title:</source>
         <translation>Titel:</translation>
     </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation>Der Titel des Dokuments.</translation>
-    </message>
     <message>
         <source>Subject:</source>
         <translation>Betreff:</translation>
@@ -155,10 +171,10 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
-        <translation>( %1 Seiten )</translation>
+        <source>%1 pages</source>
+        <translation>%1 Seiten</translation>
     </message>
 </context>
 <context>
@@ -169,16 +185,12 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
     </message>
     <message>
         <source>&amp;Preferences</source>
-        <translation>&amp;Einstellungen</translation>
+        <translation>&amp;Konfiguration</translation>
     </message>
     <message>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation>Optionen</translation>
-    </message>
     <message>
         <source>Layout</source>
         <translation>Gestaltung (Layout)</translation>
@@ -223,11 +235,11 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
     </message>
     <message>
         <source>&amp;Print</source>
-        <translation>&amp;Drucken</translation>
+        <translation>Drucke&amp;n</translation>
     </message>
     <message>
         <source>E&amp;xit</source>
-        <translation>&amp;Beenden</translation>
+        <translation>B&amp;eenden</translation>
     </message>
     <message>
         <source>Print and Close</source>
@@ -315,10 +327,6 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Insert blank page before this page</source>
         <translation>Leere Seite vor dieser Seite einfügen</translation>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation>Seiten ab hier bis zum Ende löschen.</translation>
-    </message>
     <message>
         <source>Save</source>
         <translation>Speichern</translation>
@@ -416,18 +424,10 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Rotate job to the right</source>
         <translation>Druckauftrag nach rechts drehen</translation>
     </message>
-    <message>
-        <source>Delete job</source>
-        <translation>Druckauftrag löschen</translation>
-    </message>
     <message>
         <source>Job title:</source>
         <translation>Titel des Druckauftrags:</translation>
     </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation>&amp;Exportieren...</translation>
-    </message>
     <message>
         <source>Export the project to PDF</source>
         <translation>Das Projekt als PDF exportieren</translation>
@@ -460,6 +460,63 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Ctrl+Shift+P</source>
         <translation>Strg+Umschalt+P</translation>
     </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation>Broschüre aufteilen (sub-booklets)</translation>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation>Gelöschte Seite wiederherstellen</translation>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation>Seite %1 von %2</translation>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation>Letzte Dateien</translation>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation>&amp;Seite bearbeiten</translation>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation>&amp;Auftrag bearbeiten</translation>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation>Als &amp;PDF exportieren...</translation>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation>Seiten ab hier bis zum Ende löschen</translation>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation>Aktuellen Auftrag löschen</translation>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation>Automatisches Speichern</translation>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation>Ich kann das Verzeichnis &quot;%1&quot; nicht erstellen</translation>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation>%1 %2: Seite %3</translation>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Datei &quot;%1&quot; konnte nicht geschrieben werden</translation>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -471,6 +528,10 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Number of copies:</source>
         <translation>Anzahl der Kopien:</translation>
     </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation>Kopien sortieren:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -498,10 +559,6 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Top:</source>
         <translation>Oben:</translation>
     </message>
-    <message>
-        <source>Duplex:</source>
-        <translation>Duplex:</translation>
-    </message>
     <message>
         <source>Draw border</source>
         <translation>Rahmen anzeigen</translation>
@@ -547,6 +604,38 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
         <translation>Profil %1</translation>
     </message>
+    <message>
+        <source>Color mode:</source>
+        <translation>Farbmodus:</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation>Graustufen erzwingen</translation>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation>Farbe erzwingen</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation>Doppelseitiger Druck</translation>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation>An kurzer Kante umdrehen</translation>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation>An langer Kante umdrehen</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -559,9 +648,6 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Datei &apos;%1&apos; konnte nicht geschrieben werden</translation>
     </message>
-</context>
-<context>
-    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
         <translation>Ich kann die Datei &quot;%1&quot; nicht öffnen (keine solche Datei oder Verzeichnis)</translation>
@@ -575,32 +661,23 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <translation>Ich kann die Datei &quot;%1&quot; nicht öffnen</translation>
     </message>
     <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Ich kann nicht in die Datei &apos;%1&apos; schreiben</translation>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Ich kann die Datei &quot;%1&quot; nicht lesen, weil ihr Dateityp entweder nicht unterstützt wird oder die Datei beschädigt wurde.</translation>
+    </message>
+</context>
+<context>
+    <name>ProjectFile</name>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <translation>Ich kann die Datei &quot;%1&quot; nicht öffnen</translation>
     </message>
     <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
-        <translation>Ich kann die Datei &quot;%1&quot; nicht lesen, weil ihr Dateityp entweder nicht unterstützt wird oder die Datei beschädigt ist.</translation>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Ich kann nicht in die Datei &apos;%1&apos; schreiben</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation>PDF-Datei &quot;%1&quot; ist beschädigt.</translation>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation>PDF-Datei &quot;%1&quot; ist verschlüsselt.</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Datei &quot;%1&quot; konnte nicht geöffnet werden</translation>
-    </message>
-    <message>
-        <source>Print to file (PDF)</source>
-        <translation>In Datei drucken (PDF)</translation>
-    </message>
     <message>
         <source>I can&apos;t read from file &apos;%1&apos;</source>
         <translation>Ich kann nicht aus der Datei &apos;%1&apos; lesen</translation>
@@ -626,6 +703,17 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <translation>~/Unbenannt.pdf</translation>
     </message>
 </context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation>Aufgeteilte Broschüre (sub-booklet) %1</translation>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation>%1 Seiten</translation>
+    </message>
+</context>
 <context>
     <name>TmpPdfFile</name>
     <message>
