@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -41,10 +41,6 @@
         <source>License: %1</source>
         <translation>Άδεια χρήσης: %1</translation>
     </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation>Το Boomaga αναπτύσσεται από την &lt;a %1&gt;ομάδα του Boomaga και τους συνεισφέροντες&lt;/a&gt; στο Github.</translation>
-    </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <translation>Αν επιθυμείτε να λάβετε μέρος στην ομάδα μας, &lt;a %1&gt;ελάτε μαζί μας&lt;/a&gt;.</translation>
@@ -57,28 +53,52 @@
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation>Αν επιθυμείτε να βοηθήσετε στη μετάφραση, με χαρά σας καλωσορίζουμε στην ομάδα μετάφρασης στην &lt;a %1&gt;πλατφόρμα Transifex&lt;/a&gt;.</translation>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation>Το Boomaga αναπτύσσεται από την &lt;a %1&gt;ομάδα του Boomaga και τους συνεισφέροντες&lt;/a&gt; στο GitHub.</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
     <message>
         <source>Preferences</source>
-        <translation type="unfinished"/>
+        <translation>Προτιμήσεις</translation>
     </message>
     <message>
         <source>Divide your long booklets into smaller sub-booklets for printing.</source>
-        <translation type="unfinished"/>
+        <translation>Διαιρεί τα μεγάλα βιβλιάρια σε μικρότερα υποβιβλιάρια για εκτύπωση.</translation>
     </message>
     <message>
         <source>Print as sub-booklets</source>
-        <translation type="unfinished"/>
+        <translation>Εκτύπωση ως υπο-βιβλιάρια</translation>
     </message>
     <message>
         <source>Maximum number of sheets in your sub-booklet.</source>
-        <translation type="unfinished"/>
+        <translation>Μέγιστος αριθμός φύλλων στα υπο-βιβλιάρια.</translation>
     </message>
     <message>
         <source>Sheets per sub-booklet:</source>
-        <translation type="unfinished"/>
+        <translation>Φύλλα ανά υπο-βιβλιάριο:</translation>
+    </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation>Αυτόματη αποθήκευση των εργασιών σε κάθε εκτύπωση.</translation>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation>Αυτόματη αποθήκευση των πρόσφατων συνεδριών</translation>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation>ΝΑ επιτρέπονται τα αρνητικά περιθώρια σελίδος:</translation>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation>Επιλογή καταλόγου των αποθηκευμένων εργασιών.</translation>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation>Κατάλογος των αποθηκευμένων συνεδριών:</translation>
     </message>
 </context>
 <context>
@@ -115,10 +135,6 @@
         <source>Title:</source>
         <translation>Τίτλος:</translation>
     </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation> Ο τίτλος του εγγράφου.</translation>
-    </message>
     <message>
         <source>Subject:</source>
         <translation>Θέμα:</translation>
@@ -151,14 +167,14 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source> The document&apos;s title.</source>
-        <translation type="unfinished"/>
+        <translation>  Ο τίτλος του εγγράφου.</translation>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
-        <translation>( %1 σελίδες )</translation>
+        <source>%1 pages</source>
+        <translation>%1 σελίδες</translation>
     </message>
 </context>
 <context>
@@ -175,10 +191,6 @@ Are you sure you want to overwrite it?</source>
         <source>Help</source>
         <translation>Βοήθεια</translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation>Επιλογές</translation>
-    </message>
     <message>
         <source>Layout</source>
         <translation>Διάταξη</translation>
@@ -315,161 +327,210 @@ Are you sure you want to overwrite it?</source>
         <source>Insert blank page before this page</source>
         <translation>Εισαγάγετε μια λευκή σελίδα πριν από αυτή</translation>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation>Διαγράψτε τις υπολειπόμενες σελίδες της εργασίας εκτύπωσης.</translation>
-    </message>
     <message>
         <source>Save</source>
         <translation>Αποθήκευση</translation>
     </message>
     <message>
         <source>Save project</source>
-        <translation type="unfinished"/>
+        <translation>Αποθήκευση του έργου</translation>
     </message>
     <message>
         <source>Ctrl+S</source>
-        <translation type="unfinished"/>
+        <translation>Ctrl+S</translation>
     </message>
     <message>
         <source>Save as...</source>
-        <translation type="unfinished"/>
+        <translation>Αποθήκευση ως...</translation>
     </message>
     <message>
         <source>Save project under a new name</source>
-        <translation type="unfinished"/>
+        <translation>Αποθήκευση του έργο υπό ενός νέου ονόματος</translation>
     </message>
     <message>
         <source>Ctrl+Shift+S</source>
-        <translation type="unfinished"/>
+        <translation>Ctrl+Shift+S</translation>
     </message>
     <message>
         <source>Open...</source>
-        <translation type="unfinished"/>
+        <translation>Άνοιγμα...</translation>
     </message>
     <message>
         <source>Open an existing project</source>
-        <translation type="unfinished"/>
+        <translation>Άνοιγμα ενός υπάρχοντος έργου</translation>
     </message>
     <message>
         <source>Ctrl+O</source>
-        <translation type="unfinished"/>
+        <translation>Ctrl+O</translation>
     </message>
     <message>
         <source>Page %1</source>
         <comment>'Undo deletion' menu item</comment>
-        <translation type="unfinished"/>
+        <translation>Σελίδα %1</translation>
     </message>
     <message>
         <source>Boomaga files (*.boo);;All files (*.*)</source>
-        <translation type="unfinished"/>
+        <translation>Αρχεία Boomaga  (*.boo)··Όλα τα αρχεία (*.*)</translation>
     </message>
     <message>
         <source>Project saved successfully.</source>
-        <translation type="unfinished"/>
+        <translation>Το έργο αποθηκεύτηκε επιτυχώς.</translation>
     </message>
     <message>
         <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
-        <translation type="unfinished"/>
+        <translation>Όλα τα υποστηριζόμενα αρχεία (*.pdf *.boo)··Αρχεία Boomaga (*.boo)··Αρχεία PDF (*.pdf)··΄Όλα τα αρχεία (*.*)</translation>
     </message>
     <message>
         <source>4 up horizontal</source>
-        <translation type="unfinished"/>
+        <translation>Τετράδα οριζόντια</translation>
     </message>
     <message>
         <source>4 up vertical</source>
-        <translation type="unfinished"/>
+        <translation>Τετράδα κατακόρυφα</translation>
     </message>
     <message>
         <source>8 up horizontal</source>
-        <translation type="unfinished"/>
+        <translation>Οκτάδα οριζόντια</translation>
     </message>
     <message>
         <source>8 up vertical</source>
-        <translation type="unfinished"/>
+        <translation>Οκτάδα κατακόρυφα</translation>
     </message>
     <message>
         <source>Start new booklet from this page</source>
-        <translation type="unfinished"/>
+        <translation>Δημιουργία ενός νέου βιβλιαρίου από από αυτήν τη σελίδα</translation>
     </message>
     <message>
         <source>Don&apos;t start new booklet from this page</source>
-        <translation type="unfinished"/>
+        <translation>Να μην γίνει δημιουργία ενός νέου βιβλιαρίου από αυτήν την σελίδα</translation>
     </message>
     <message>
         <source>Rotate page to the left</source>
-        <translation type="unfinished"/>
+        <translation>Περιστροφή της σελίδας αριστερά</translation>
     </message>
     <message>
         <source>Rotate page to the right</source>
-        <translation type="unfinished"/>
+        <translation>Περιστροφή της σελίδας δεξιά</translation>
     </message>
     <message>
         <source>Rename job</source>
-        <translation type="unfinished"/>
+        <translation>Μετονομασία της εργασίας</translation>
     </message>
     <message>
         <source>Rotate job to the left</source>
-        <translation type="unfinished"/>
+        <translation>Περιστροφή της εργασίας αριστερά</translation>
     </message>
     <message>
         <source>Rotate job to the right</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Delete job</source>
-        <translation type="unfinished"/>
+        <translation>Περιστροφή της εργασίας δεξιά</translation>
     </message>
     <message>
         <source>Job title:</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation type="unfinished"/>
+        <translation>Τίτλος εργασίας:</translation>
     </message>
     <message>
         <source>Export the project to PDF</source>
-        <translation type="unfinished"/>
+        <translation>Εξαγωγή του έργου ως PDF</translation>
     </message>
     <message>
         <source>Ctrl+E</source>
-        <translation type="unfinished"/>
+        <translation>Ctrl+E</translation>
     </message>
     <message>
         <source>Clone job...</source>
-        <translation type="unfinished"/>
+        <translation>Κλωνοποίηση της εργασίας...</translation>
     </message>
     <message>
         <source>Clone job</source>
-        <translation type="unfinished"/>
+        <translation>Κλωνοποίηση της εργασίας</translation>
     </message>
     <message>
         <source>Number of copies:</source>
-        <translation type="unfinished"/>
+        <translation>Αριθμός αντιγράφων:</translation>
     </message>
     <message>
         <source>Print with options...</source>
-        <translation type="unfinished"/>
+        <translation>Εκτύπωση με επιλογές...</translation>
     </message>
     <message>
         <source>Select number of copies before printing.</source>
-        <translation type="unfinished"/>
+        <translation>Επιλκέξτε τον αριθμό των αντιγράφων πριν την εκτύπωση.</translation>
     </message>
     <message>
         <source>Ctrl+Shift+P</source>
-        <translation type="unfinished"/>
+        <translation>Ctrl+Shift+P</translation>
+    </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation>Υπο-βιβλιάρια</translation>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation>Αναίρεση της διαγραφής της σελίδας</translation>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation>Σελίδα %1 από %2</translation>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation>Πρόσφατα αρχεία</translation>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation>&amp;Επεξεργασία σελίδας</translation>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation>Επεξεργασία ε&amp;ργασίας</translation>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation>Εξαγωγή σε &amp;PDF...</translation>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation>Διαγράψτε τις υπολειπόμενες σελίδες της εργασίας εκτύπωσης</translation>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation>Διαγραφή της τρέχουσας εργασίας</translation>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation>Αυτόματη αποθήκευση</translation>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation>Αδύνατη η δημιουργία του καταλόγου «%1»</translation>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation>%1 %2: Σελίδα %3</translation>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Αδύνατη η εγγραφή του αρχείου «%1»</translation>
     </message>
 </context>
 <context>
     <name>PrintDialog</name>
     <message>
         <source>Print document</source>
-        <translation type="unfinished"/>
+        <translation>Εκτύπωση του εγγράφου</translation>
     </message>
     <message>
         <source>Number of copies:</source>
-        <translation type="unfinished"/>
+        <translation>Αριθμός αντιγράφων:</translation>
+    </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation>Τοποθέτηση σε σειρά των αντιγράφων:</translation>
     </message>
 </context>
 <context>
@@ -498,10 +559,6 @@ Are you sure you want to overwrite it?</source>
         <source>Top:</source>
         <translation>Πάνω:</translation>
     </message>
-    <message>
-        <source>Duplex:</source>
-        <translation>Διπλής όψης:</translation>
-    </message>
     <message>
         <source>Draw border</source>
         <translation>Σχεδίαση περιγράμματος</translation>
@@ -528,24 +585,56 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Profiles</source>
-        <translation type="unfinished"/>
+        <translation>Ταυτότητες</translation>
     </message>
     <message>
         <source>+</source>
-        <translation type="unfinished"/>
+        <translation>+</translation>
     </message>
     <message>
         <source>-</source>
-        <translation type="unfinished"/>
+        <translation>-</translation>
     </message>
     <message>
         <source>Reset to default</source>
-        <translation type="unfinished"/>
+        <translation>Επαναφορά στο προκαθορισμένο</translation>
     </message>
     <message>
         <source>Profile %1</source>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
-        <translation type="unfinished"/>
+        <translation>Ταυτότητα %1</translation>
+    </message>
+    <message>
+        <source>Color mode:</source>
+        <translation>Λειτουργία χρώματος:</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Εξ ορισμού</translation>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation>Εξαναγκασμός ασπρόμαυρου χρωματισμού</translation>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation>Εξαναγκασμός χρώματος</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Ρυθμίσεις</translation>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation>Εκτύπωση στις δυο πλευρές</translation>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation>Αλλαγή πλευράς σε κοντή άκρη</translation>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation>Αλλαγή πλευράς σε μακριά άκρη</translation>
     </message>
 </context>
 <context>
@@ -559,71 +648,70 @@ Are you sure you want to overwrite it?</source>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Αδύνατη η εγγραφή στο αρχείο «%1»</translation>
     </message>
-</context>
-<context>
-    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation type="unfinished"/>
+        <translation>Δεν μπορώ να ανοίξω το αρχείο «%1» (Δεν υπάρχει τέτοιο αρχείο ή κατάλογος)</translation>
     </message>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation>Το αρχείο PDF «%1» είναι κατεστραμμένο.</translation>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation>Το αρχείο PDF «%1» είναι κρυπτογραφημένο.</translation>
+        <translation>Δεν μπορώ να ανοίξω το αρχείο «%1» (Άρνηση πρόσβασης)</translation>
     </message>
     <message>
         <source>I can&apos;t open file &quot;%1&quot;</source>
         <translation>Αδύνατο το άνοιγμα του αρχείου «%1»</translation>
     </message>
     <message>
-        <source>Print to file (PDF)</source>
-        <translation>Εκτύπωση σε αρχείο (PDF)</translation>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Δεν μπορώ να αναγνώσω του αρχείο «%1» είτε λόγω ενός μη υποστηριζόμενου τύπου αρχείου, είτε λόγω ενός κατεστραμμένου αρχείου.</translation>
     </message>
+</context>
+<context>
+    <name>ProjectFile</name>
     <message>
-        <source>I can&apos;t read from file &apos;%1&apos;</source>
-        <translation type="unfinished"/>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <translation>Αδύνατο το άνοιγμα του αρχείου «%1»</translation>
     </message>
     <message>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation type="unfinished"/>
+        <translation>Αδύνατη η εγγραφή στο αρχείο «%1»</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>I can&apos;t read from file &apos;%1&apos;</source>
+        <translation>Δεν μπορώ να αναγνώσω από το αρχείο «%1»</translation>
+    </message>
+    <message>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Αδύνατη η εγγραφή στο αρχείο «%1»</translation>
     </message>
     <message>
         <source>Untitled</source>
-        <translation type="unfinished"/>
+        <translation>Άτιτλο</translation>
     </message>
     <message>
         <source>Default</source>
         <comment>Printer profile default name</comment>
-        <translation type="unfinished"/>
+        <translation>Εξ ορισμού</translation>
     </message>
 </context>
 <context>
     <name>Settings</name>
     <message>
         <source>~/Untitled.pdf</source>
-        <translation>~/Untitled.pdf</translation>
+        <translation>~/Άτιτλο.pdf</translation>
+    </message>
+</context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation>Υπο-βιβλιάριο %1</translation>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation>%1 σελίδες</translation>
     </message>
 </context>
 <context>
