@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -7,7 +7,7 @@
     </message>
     <message>
         <source>About</source>
-        <translation>À propos de</translation>
+        <translation>À propos</translation>
     </message>
     <message>
         <source>Authors</source>
@@ -23,7 +23,7 @@
     </message>
     <message>
         <source>Version: %1</source>
-        <translation>Version : %1</translation>
+        <translation>Version : %1</translation>
     </message>
     <message>
         <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
@@ -31,19 +31,15 @@
     </message>
     <message>
         <source>Copyright: %1-%2 %3</source>
-        <translation>Tous droits réservés : %1-%2 %3</translation>
+        <translation>Tous droits réservés : %1-%2 %3</translation>
     </message>
     <message>
         <source>Homepage: %1</source>
-        <translation>Page d&apos;accueil : %1</translation>
+        <translation>Page d’accueil : %1</translation>
     </message>
     <message>
         <source>License: %1</source>
-        <translation>Licence : %1</translation>
-    </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation>Boomaga est développé par l&apos;&lt;a %1&gt;équipe Boomaga et ses contributeurs&lt;/a&gt; sur Github.</translation>
+        <translation>Licence : %1</translation>
     </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
@@ -51,12 +47,16 @@
     </message>
     <message>
         <source>Special thanks to:</source>
-        <translation>Remerciements particuliers à :</translation>
+        <translation>Remerciements particuliers à :</translation>
     </message>
     <message>
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation>Si vous désirez aider à traduire, nous serons heureux de vous accueillir dans notre équipe de traduction sur le &lt;a %1&gt;serveur Transifex&lt;/a&gt;.</translation>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation>Boomaga est développé par l’&lt;a %1&gt;équipe Boomaga et ses contributeurs&lt;/a&gt; sur GitHub.</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -66,7 +66,7 @@
     </message>
     <message>
         <source>Divide your long booklets into smaller sub-booklets for printing.</source>
-        <translation>Divisez vos livrets longs en de plus petits, pour l&apos;impression.</translation>
+        <translation>Divisez vos livrets longs en de plus petits, pour l’impression.</translation>
     </message>
     <message>
         <source>Print as sub-booklets</source>
@@ -78,7 +78,27 @@
     </message>
     <message>
         <source>Sheets per sub-booklet:</source>
-        <translation>Feuilles dans votre sous-livret :</translation>
+        <translation>Feuilles dans votre sous-livret :</translation>
+    </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation>Enregistrer automatiquement vos travaux lors de chaque impression</translation>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation>Enregistrer automatiquement les sessions récentes</translation>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation>Autoriser les marges négatives :</translation>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation>Sélectionner le répertoire des travaux enregistrés</translation>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation>Répertoire des travaux enregistrés :</translation>
     </message>
 </context>
 <context>
@@ -93,7 +113,7 @@
     </message>
     <message>
         <source>Output file:</source>
-        <translation>Fichier de sortie :</translation>
+        <translation>Fichier de sortie :</translation>
     </message>
     <message>
         <source>...</source>
@@ -105,7 +125,7 @@
     </message>
     <message>
         <source>Author:</source>
-        <translation>Auteur :</translation>
+        <translation>Auteur :</translation>
     </message>
     <message>
         <source> The name of the person who created the document.</source>
@@ -113,19 +133,15 @@
     </message>
     <message>
         <source>Title:</source>
-        <translation>Titre :</translation>
-    </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation>Le titre du document.</translation>
+        <translation>Titre :</translation>
     </message>
     <message>
         <source>Subject:</source>
-        <translation>Objet :</translation>
+        <translation>Objet :</translation>
     </message>
     <message>
         <source> The subject of the document.</source>
-        <translation>L&apos;objet du document.</translation>
+        <translation>L’objet du document.</translation>
     </message>
     <message>
         <source> Keywords associated with the document.</source>
@@ -133,7 +149,7 @@
     </message>
     <message>
         <source>Keywords:</source>
-        <translation>Mots-clefs :</translation>
+        <translation>Mots-clés :</translation>
     </message>
     <message>
         <source>PDF files (*.pdf);;All files (*.*)</source>
@@ -141,13 +157,13 @@
     </message>
     <message>
         <source>Overwrite file?</source>
-        <translation>Écraser le fichier ?</translation>
+        <translation>Écraser le fichier ?</translation>
     </message>
     <message>
         <source>A file named &quot;%1&quot; already exists.
 Are you sure you want to overwrite it?</source>
-        <translation>Un fichier nommé « %1 » existe déjà.
-Êtes-vous sûr de vouloir l&apos;écraser ?</translation>
+        <translation>Un fichier nommé « %1 » existe déjà.
+Êtes-vous sûr de vouloir l’écraser ?</translation>
     </message>
     <message>
         <source> The document&apos;s title.</source>
@@ -155,10 +171,10 @@ Are you sure you want to overwrite it?</source>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
-        <translation>( %1 pages )</translation>
+        <source>%1 pages</source>
+        <translation>%1 pages</translation>
     </message>
 </context>
 <context>
@@ -175,10 +191,6 @@ Are you sure you want to overwrite it?</source>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation>Options</translation>
-    </message>
     <message>
         <source>Layout</source>
         <translation>Mise en page</translation>
@@ -198,7 +210,7 @@ Are you sure you want to overwrite it?</source>
     <message>
         <source>Print on both sides of a sheet.</source>
         <comment>MainForm::Double-sided checkbox tooltip</comment>
-        <translation>Imprimer sur les deux côtés d&apos;une feuille.</translation>
+        <translation>Imprimer sur les deux côtés d’une feuille.</translation>
     </message>
     <message>
         <source>Double-sided</source>
@@ -219,7 +231,7 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Toolbar</source>
-        <translation>Barre d&apos;outils</translation>
+        <translation>Barre d’outils</translation>
     </message>
     <message>
         <source>&amp;Print</source>
@@ -264,7 +276,7 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
-        <translation>Imprimer les pages impaires sur %1.&lt;p&gt;Une fois terminé, tourner les pages, les insérer dans l&apos;imprimante&lt;br&gt;et cliquer sur le bouton Continue.</translation>
+        <translation>Imprimer les pages impaires sur %1.&lt;p&gt;Une fois terminé, tourner les pages, les insérer dans l’imprimante&lt;br&gt;et cliquer sur le bouton Continue.</translation>
     </message>
     <message>
         <source>Print the even pages on %1.</source>
@@ -315,10 +327,6 @@ Are you sure you want to overwrite it?</source>
         <source>Insert blank page before this page</source>
         <translation>Insérer une page blanche avant cette page</translation>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation>Supprimer les pages restantes du travail.</translation>
-    </message>
     <message>
         <source>Save</source>
         <translation>Enregistrer</translation>
@@ -416,17 +424,9 @@ Are you sure you want to overwrite it?</source>
         <source>Rotate job to the right</source>
         <translation>Tourner le travail vers la droite</translation>
     </message>
-    <message>
-        <source>Delete job</source>
-        <translation>Supprimer le travail</translation>
-    </message>
     <message>
         <source>Job title:</source>
-        <translation>Titre du travail :</translation>
-    </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation>&amp;Exporter...</translation>
+        <translation>Titre du travail :</translation>
     </message>
     <message>
         <source>Export the project to PDF</source>
@@ -446,7 +446,7 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Number of copies:</source>
-        <translation>Nombre de copies :</translation>
+        <translation>Nombre de copies :</translation>
     </message>
     <message>
         <source>Print with options...</source>
@@ -454,12 +454,69 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Select number of copies before printing.</source>
-        <translation>Choisir le nombre de copies avant d&apos;imprimer.</translation>
+        <translation>Choisir le nombre de copies avant d’imprimer.</translation>
     </message>
     <message>
         <source>Ctrl+Shift+P</source>
         <translation>Ctrl+Maj+P</translation>
     </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation>Sous-livrets</translation>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation>Annuler la suppression de page</translation>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation>Page %1 de %2</translation>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation>Fichiers récents</translation>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation>&amp;Modifier la page</translation>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation>Modifier le &amp;travail</translation>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation>&amp;Exporter en PDF...</translation>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation>Supprimer cette page et les suivantes</translation>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation>Supprimer le travail actuel</translation>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation>Enregistrement automatique</translation>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation>Je ne peux pas créer le répertoire « %1 »</translation>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation>%1 %2 : page %3</translation>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -469,7 +526,11 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Number of copies:</source>
-        <translation>Nombre de copies :</translation>
+        <translation>Nombre de copies :</translation>
+    </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation>Collationner les copies :</translation>
     </message>
 </context>
 <context>
@@ -480,27 +541,23 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Right:</source>
-        <translation>Droite :</translation>
+        <translation>Droite :</translation>
     </message>
     <message>
         <source>Bottom:</source>
-        <translation>Bas :</translation>
+        <translation>Bas :</translation>
     </message>
     <message>
         <source>Internal:</source>
-        <translation>Interne :</translation>
+        <translation>Interne :</translation>
     </message>
     <message>
         <source>Left:</source>
-        <translation>Gauche :</translation>
+        <translation>Gauche :</translation>
     </message>
     <message>
         <source>Top:</source>
-        <translation>Haut :</translation>
-    </message>
-    <message>
-        <source>Duplex:</source>
-        <translation>Recto-verso :</translation>
+        <translation>Haut :</translation>
     </message>
     <message>
         <source>Draw border</source>
@@ -547,6 +604,38 @@ Are you sure you want to overwrite it?</source>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
         <translation>Profil %1</translation>
     </message>
+    <message>
+        <source>Color mode:</source>
+        <translation>Mode chromatique :</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Par défaut</translation>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation>Forcer l’échelle de gris</translation>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation>Forcer la couleur</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Paramètres</translation>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation>Imprimer sur les deux côtés</translation>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation>Inverser sur le bord court</translation>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation>Inverser sur le bord long</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -557,57 +646,45 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
+        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
+        <translation>Je ne peux pas ouvrir le fichier « %1 » (fichier ou répertoire inexistant)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
+        <translation>Je ne peux pas ouvrir le fichier « %1 » (accès refusé)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <translation>Je ne peux pas ouvrir le fichier « %1 »</translation>
+    </message>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Je ne peux pas lire le fichier « %1 ». Soit ce n’est pas un type de fichier pris en charge, soit le fichier est endommagé.</translation>
     </message>
 </context>
 <context>
     <name>ProjectFile</name>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation>Je ne peux pas ouvrir le fichier « %1 » (fichier ou répertoire inexistant)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation>Je ne peux pas ouvrir le fichier « %1 » (accès refusé)</translation>
-    </message>
     <message>
         <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Je ne peux pas ouvrir le fichier « %1 »</translation>
+        <translation>Je ne peux pas ouvrir le fichier « %1 »</translation>
     </message>
     <message>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
-        <translation>Je ne peux pas lire le fichier « %1 » car il n&apos;est pas pris en charge ou car le fichier est endommagé.</translation>
+        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation>Le fichier PDF « %1 » est endommagé.</translation>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation>Le fichier PDF « %1 » est chiffré.</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Je ne peux pas ouvrir le fichier « %1 »</translation>
-    </message>
-    <message>
-        <source>Print to file (PDF)</source>
-        <translation>Imprimer vers un fichier (PDF)</translation>
-    </message>
     <message>
         <source>I can&apos;t read from file &apos;%1&apos;</source>
-        <translation>Je ne peux pas lire le fichier « %1 »</translation>
+        <translation>Je ne peux pas lire le fichier « %1 »</translation>
     </message>
     <message>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
+        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
     </message>
     <message>
         <source>Untitled</source>
@@ -626,11 +703,22 @@ Are you sure you want to overwrite it?</source>
         <translation>~/Sansnom.pdf</translation>
     </message>
 </context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation>Sous-livret %1</translation>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation>%1 pages</translation>
+    </message>
+</context>
 <context>
     <name>TmpPdfFile</name>
     <message>
         <source>I can&apos;t create temporary file &quot;%1&quot;</source>
-        <translation>Je ne peux pas créer le fichier temporaire « %1 »</translation>
+        <translation>Je ne peux pas créer le fichier temporaire « %1 »</translation>
     </message>
     <message>
         <source>Something is wrong. I can't find boomagamerger program.
@@ -640,11 +728,11 @@ Veuillez me réinstaller.</translation>
     </message>
     <message>
         <source>I can&apos;t read file &apos;%1&apos;</source>
-        <translation>Je ne peux pas lire le fichier « %1 »</translation>
+        <translation>Je ne peux pas lire le fichier « %1 »</translation>
     </message>
     <message>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
+        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
