@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -41,10 +41,6 @@
         <source>License: %1</source>
         <translation>Licenza: %1</translation>
     </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation>Boomaga è sviluppato dal &lt;a %1&gt;Team Boomaga e contributori&lt;/a&gt; su Github.</translation>
-    </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <translation>Se sei interessato a lavorare con il nostro team di sviluppo, &lt;a %1&gt;unisciti a noi&lt;/a&gt;.</translation>
@@ -57,6 +53,10 @@
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation>Se desideri aiutare a tradurre, saremo felici di vederti nel nostro team di traduzione su &lt;a %1&gt;server Transifex&lt;/a&gt;.</translation>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation>Boomaga è sviluppato dal Team &lt;a %1&gt;Boomaga e dai  contributori&lt;/a&gt; su GitHub.</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -80,12 +80,32 @@
         <source>Sheets per sub-booklet:</source>
         <translation>Fogli per sotto-fascicolo:</translation>
     </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation>Salva automaticamente i tuoi lavori di stampa ogni volta che stampi.</translation>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation>Salva automaticamente le sessioni recenti</translation>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation>Consenti margini negativi per le pagine:</translation>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation>Seleziona la cartella per i lavori di stampa salvati.</translation>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation>Cartella per le sessioni salvate:</translation>
+    </message>
 </context>
 <context>
     <name>ExportToPdf</name>
     <message>
         <source>Print to PDF</source>
-        <translation>Stampare su PDF</translation>
+        <translation>Stampa in PDF</translation>
     </message>
     <message>
         <source>File name</source>
@@ -115,10 +135,6 @@
         <source>Title:</source>
         <translation>Titolo:</translation>
     </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation>Il titolo del documento.</translation>
-    </message>
     <message>
         <source>Subject:</source>
         <translation>Oggetto:</translation>
@@ -155,10 +171,10 @@ Sei sicuro di volerlo sovracrivere?</translation>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
-        <translation>( %1 pagine )</translation>
+        <source>%1 pages</source>
+        <translation>%1 pagine</translation>
     </message>
 </context>
 <context>
@@ -175,10 +191,6 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Help</source>
         <translation>Aiuto</translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation>Opzioni</translation>
-    </message>
     <message>
         <source>Layout</source>
         <translation>Disposizione</translation>
@@ -315,10 +327,6 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Insert blank page before this page</source>
         <translation>Inserisci una pagina vuota prima di questa pagina</translation>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation>Rimuovere le pagine fino alla fine del lavoro di stampa.</translation>
-    </message>
     <message>
         <source>Save</source>
         <translation>Salva</translation>
@@ -416,18 +424,10 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Rotate job to the right</source>
         <translation>Ruotare il lavoro di stampa verso destra</translation>
     </message>
-    <message>
-        <source>Delete job</source>
-        <translation>Cancellare il lavoro di stampa</translation>
-    </message>
     <message>
         <source>Job title:</source>
         <translation>Nome del lavoro di stampa:</translation>
     </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation>&amp;Esportare...</translation>
-    </message>
     <message>
         <source>Export the project to PDF</source>
         <translation>Esportare il progetto in PDF</translation>
@@ -460,6 +460,63 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Ctrl+Shift+P</source>
         <translation>Ctrl+Shift+P</translation>
     </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation>Sotto-fascicoli</translation>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation>Annulla eliminazione pagina</translation>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation>Pagina %1 di %2</translation>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation>File recenti</translation>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation>&amp;Modifica pagina</translation>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation>Modifica &amp;lavoro di stampa</translation>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation>&amp;Esporta in PDF...</translation>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation>Cancella le pagine fino alla fine del lavoro di stampa</translation>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation>Cancella il lavoro di stampa corrente</translation>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation>Auto salvataggio</translation>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation>Non posso creare la cartella &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation>%1 %2: Pagina %3</translation>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Non riesco a scrivere il file &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -471,6 +528,10 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Number of copies:</source>
         <translation>Numero di copie:</translation>
     </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation>Fascicola copie:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -498,10 +559,6 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Top:</source>
         <translation>In alto:</translation>
     </message>
-    <message>
-        <source>Duplex:</source>
-        <translation>Duplex:</translation>
-    </message>
     <message>
         <source>Draw border</source>
         <translation>Disegnare il bordo</translation>
@@ -547,6 +604,38 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
         <translation>Profilo %1</translation>
     </message>
+    <message>
+        <source>Color mode:</source>
+        <translation>Modalità colore:</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Predefinito</translation>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation>Forza la scala di grigio</translation>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation>Forza il colore</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Impostazioni</translation>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation>Stampa su entrambi i lati</translation>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation>Sfoglia sul lato corto</translation>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation>Sfoglia sul lato lungo</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -559,9 +648,6 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Non riesco a scrivere sul file &apos;%1&apos;</translation>
     </message>
-</context>
-<context>
-    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
         <translation>Non posso aprire il file &quot;%1&quot; (File o cartella non esistenti)</translation>
@@ -575,32 +661,23 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <translation>Non posso aprire il file &quot;%1&quot;</translation>
     </message>
     <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Non posso scrivere nel file &apos;%1&apos;</translation>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Non posso leggere il file &quot;%1&quot; perché è un tipo di file non supportato, oppure il file è stato danneggiato.</translation>
+    </message>
+</context>
+<context>
+    <name>ProjectFile</name>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <translation>Non posso aprire il file &quot;%1&quot;</translation>
     </message>
     <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
-        <translation>Non posso leggere il file &quot;%1&quot; perché è un tipo di file non supportato oppure il file è stato danneggiato.</translation>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Non posso scrivere nel file &apos;%1&apos;</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation>Il file PDF &quot;%1&quot; è danneggiato.</translation>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation>Il file PDF &quot;%1&quot; è crittografato.</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Non riesco ad aprire il file &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>Print to file (PDF)</source>
-        <translation>Stampare su file (PDF)</translation>
-    </message>
     <message>
         <source>I can&apos;t read from file &apos;%1&apos;</source>
         <translation>Non posso leggere dal file &apos;%1&apos;</translation>
@@ -626,6 +703,17 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <translation>~/Senza titolo.pdf</translation>
     </message>
 </context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation>Sotto-fascicolo %1</translation>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation>%1 pagine</translation>
+    </message>
+</context>
 <context>
     <name>TmpPdfFile</name>
     <message>
