@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -31,7 +31,7 @@
     </message>
     <message>
         <source>Copyright: %1-%2 %3</source>
-        <translation>Autorinės Teisės: %1-%2 %3</translation>
+        <translation>Autorių Teisės: %1-%2 %3</translation>
     </message>
     <message>
         <source>Homepage: %1</source>
@@ -41,10 +41,6 @@
         <source>License: %1</source>
         <translation>Licencija: %1</translation>
     </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation>Boomaga yra sukurta &lt;a %1&gt;Boomaga Komandos ir talkininkų&lt;/a&gt; sistemoje Github.</translation>
-    </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <translation>Jeigu jus sudomino darbas su mūsų kūrėjų komanda, &lt;a %1&gt;prisijunkite prie mūsų&lt;/a&gt;.</translation>
@@ -57,6 +53,10 @@
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation>Jeigu jūs norėtumėte padėti išversti programą, mums būtų malonu matyti jus mūsų komandoje &lt;a %1&gt;Transifex serveryje&lt;/a&gt;.</translation>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation>Boomaga yra sukurta &lt;a %1&gt;Boomaga komandos ir talkininkų&lt;/a&gt; sistemoje GitHub.</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -80,6 +80,26 @@
         <source>Sheets per sub-booklet:</source>
         <translation>Lapų skaičius brošiūrėlėje:</translation>
     </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation>Automatiškai įrašyti jūsų darbus kas kartą jums spausdinant.</translation>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation>Automatiškai įrašyti paskiausius seansus</translation>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation>Leisti neigiamas puslapio paraštes:</translation>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation>Pasirinkite katalogą įrašytiems darbams.</translation>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation>Katalogas, skirtas įrašytiems seansams:</translation>
+    </message>
 </context>
 <context>
     <name>ExportToPdf</name>
@@ -115,10 +135,6 @@
         <source>Title:</source>
         <translation>Pavadinimas:</translation>
     </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation>Dokumento pavadinimas.</translation>
-    </message>
     <message>
         <source>Subject:</source>
         <translation>Tema:</translation>
@@ -155,10 +171,10 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
-        <translation>( %1 puslapių )</translation>
+        <source>%1 pages</source>
+        <translation>%1 puslapių</translation>
     </message>
 </context>
 <context>
@@ -175,10 +191,6 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>Help</source>
         <translation>Pagalba</translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation>Parinktys</translation>
-    </message>
     <message>
         <source>Layout</source>
         <translation>Išdėstymas</translation>
@@ -231,7 +243,7 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
     <message>
         <source>Print and Close</source>
-        <translation>Spausdinti ir Uždaryti</translation>
+        <translation>Spausdinti ir užverti</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -315,17 +327,13 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>Insert blank page before this page</source>
         <translation>Prieš šį puslapį įterpti tuščią puslapį</translation>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation>ištrinti puslapius iki pat darbo galo.</translation>
-    </message>
     <message>
         <source>Save</source>
-        <translation>Išsaugoti</translation>
+        <translation>Įrašyti</translation>
     </message>
     <message>
         <source>Save project</source>
-        <translation>Išsaugoti projektą</translation>
+        <translation>Įrašyti projektą</translation>
     </message>
     <message>
         <source>Ctrl+S</source>
@@ -333,11 +341,11 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
     <message>
         <source>Save as...</source>
-        <translation>Išsaugoti kaip...</translation>
+        <translation>Įrašyti kaip...</translation>
     </message>
     <message>
         <source>Save project under a new name</source>
-        <translation>Išsaugoti projektą nauju pavadinimu</translation>
+        <translation>Įrašyti projektą nauju pavadinimu</translation>
     </message>
     <message>
         <source>Ctrl+Shift+S</source>
@@ -345,11 +353,11 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
     <message>
         <source>Open...</source>
-        <translation>Atidaryti...</translation>
+        <translation>Atverti...</translation>
     </message>
     <message>
         <source>Open an existing project</source>
-        <translation>Atidaryti egzistuojantį projektą</translation>
+        <translation>Atverti egzistuojantį projektą</translation>
     </message>
     <message>
         <source>Ctrl+O</source>
@@ -366,7 +374,7 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
     <message>
         <source>Project saved successfully.</source>
-        <translation>Projektas sėkmingai išsaugotas.</translation>
+        <translation>Projektas sėkmingai įrašytas.</translation>
     </message>
     <message>
         <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
@@ -416,18 +424,10 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>Rotate job to the right</source>
         <translation>Pasukti darbą į dešinę</translation>
     </message>
-    <message>
-        <source>Delete job</source>
-        <translation>Ištrinti darbą</translation>
-    </message>
     <message>
         <source>Job title:</source>
         <translation>Darbo pavadinimas:</translation>
     </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation>&amp;Eksportuoti...</translation>
-    </message>
     <message>
         <source>Export the project to PDF</source>
         <translation>Eksportuoti projektą kaip PDF</translation>
@@ -438,11 +438,11 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
     <message>
         <source>Clone job...</source>
-        <translation>Dublikuoti darbą...</translation>
+        <translation>Dubliuoti darbą...</translation>
     </message>
     <message>
         <source>Clone job</source>
-        <translation>Dublikuoti darbą</translation>
+        <translation>Dubliuoti darbą</translation>
     </message>
     <message>
         <source>Number of copies:</source>
@@ -460,6 +460,63 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>Ctrl+Shift+P</source>
         <translation>Ctrl+Shift+P</translation>
     </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation>Brošiūrėlės</translation>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation>Atšaukti puslapio ištrynimą</translation>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation>Puslapis %1 iš %2</translation>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation>Paskiausiai naudoti failai</translation>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation>R&amp;edaguoti puslapį</translation>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation>Taisyti &amp;darbą</translation>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation>&amp;Eksportuoti į PDF...</translation>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation>Ištrinti puslapius iki pat darbo galo</translation>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation>Ištrinti esamą darbą</translation>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation>Automatinis įrašymas</translation>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation>Negaliu sukurti katalogo &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation>%1 %2: Puslapis %3</translation>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Nepavyksta rašyti failo &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -471,6 +528,10 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>Number of copies:</source>
         <translation>Kopijų skaičius:</translation>
     </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation>Surikiuoti kopijas:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -498,10 +559,6 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>Top:</source>
         <translation>Viršus:</translation>
     </message>
-    <message>
-        <source>Duplex:</source>
-        <translation>Dvipusis:</translation>
-    </message>
     <message>
         <source>Draw border</source>
         <translation>Braižyti rėmelį</translation>
@@ -540,13 +597,45 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
     <message>
         <source>Reset to default</source>
-        <translation>Atstatyti numatytasias reikšmes</translation>
+        <translation>Atstatyti numatytąsias reikšmes</translation>
     </message>
     <message>
         <source>Profile %1</source>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
         <translation>Profilis %1</translation>
     </message>
+    <message>
+        <source>Color mode:</source>
+        <translation>Spalvos veiksena:</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Numatytasis</translation>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation>Priverstinai pilkio pustoniais</translation>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation>Priverstinai spalvotai</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Nustatymai</translation>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation>Spausdinti iš abiejų pusių</translation>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation>Apversti per trumpąjį kraštą</translation>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation>Apversti per ilgąjį kraštą</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -559,48 +648,36 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
     </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
+        <translation>Negaliu atverti failo &quot;%1&quot; (Nėra tokio failo ar katalogo)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
+        <translation>Negaliu atverti failo &quot;%1&quot; (Prieiga negalima)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <translation>Negaliu atverti failo &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Negaliu perskaityti failo &quot;%1&quot;, nes arba jis yra nepalaikomo failo tipo, arba jis yra pažeistas.</translation>
+    </message>
 </context>
 <context>
     <name>ProjectFile</name>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation>Negaliu atidaryti failo &quot;%1&quot; (Nėra tokio failo ar katalogo)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation>Negaliu atidaryti failo &quot;%1&quot; (Prieiga nesuteikta)</translation>
-    </message>
     <message>
         <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Negaliu atidaryti failo &quot;%1&quot;</translation>
+        <translation>Negaliu atverti failo &quot;%1&quot;</translation>
     </message>
     <message>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
     </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
-        <translation>Negaliu perskaityti failo &quot;%1&quot;, nes arba jis yra nepalaikomo failų tipo, arba failas yra pažeistas.</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation>PDF failas &quot;%1&quot; yra pažeistas.</translation>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation>PDF failas &quot;%1&quot; yra užšifruotas.</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Negaliu atidaryti failo &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>Print to file (PDF)</source>
-        <translation>Spausdinti į failą (PDF)</translation>
-    </message>
     <message>
         <source>I can&apos;t read from file &apos;%1&apos;</source>
         <translation>Negaliu perskaityti iš failo &apos;%1&apos;</translation>
@@ -626,6 +703,17 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <translation>~/Bevardis.pdf</translation>
     </message>
 </context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation>Brošiūrėlė %1</translation>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation>%1 puslapių</translation>
+    </message>
+</context>
 <context>
     <name>TmpPdfFile</name>
     <message>
