@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -41,10 +41,6 @@
         <source>License: %1</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <translation type="unfinished"/>
@@ -57,6 +53,10 @@
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -80,6 +80,26 @@
         <source>Sheets per sub-booklet:</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ExportToPdf</name>
@@ -115,10 +135,6 @@
         <source>Title:</source>
         <translation type="unfinished"/>
     </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Subject:</source>
         <translation type="unfinished"/>
@@ -154,9 +170,9 @@ Are you sure you want to overwrite it?</source>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
+        <source>%1 pages</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -174,10 +190,6 @@ Are you sure you want to overwrite it?</source>
         <source>Help</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Options</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Layout</source>
         <translation type="unfinished"/>
@@ -314,10 +326,6 @@ Are you sure you want to overwrite it?</source>
         <source>Insert blank page before this page</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Save</source>
         <translation type="unfinished"/>
@@ -415,18 +423,10 @@ Are you sure you want to overwrite it?</source>
         <source>Rotate job to the right</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Delete job</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Job title:</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Export the project to PDF</source>
         <translation type="unfinished"/>
@@ -459,6 +459,63 @@ Are you sure you want to overwrite it?</source>
         <source>Ctrl+Shift+P</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -470,6 +527,10 @@ Are you sure you want to overwrite it?</source>
         <source>Number of copies:</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -497,10 +558,6 @@ Are you sure you want to overwrite it?</source>
         <source>Top:</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Duplex:</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Draw border</source>
         <translation type="unfinished"/>
@@ -546,6 +603,38 @@ Are you sure you want to overwrite it?</source>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Color mode:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -558,9 +647,6 @@ Are you sure you want to overwrite it?</source>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation type="unfinished"/>
     </message>
-</context>
-<context>
-    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
         <translation type="unfinished"/>
@@ -574,32 +660,23 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
         <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation type="unfinished"/>
-    </message>
+    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot;</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Print to file (PDF)</source>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>QObject</name>
     <message>
         <source>I can&apos;t read from file &apos;%1&apos;</source>
         <translation type="unfinished"/>
@@ -625,6 +702,17 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>TmpPdfFile</name>
     <message>
