@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -27,7 +27,7 @@
     </message>
     <message>
         <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
-        <translation>Boomaga это виртуальный принтер для CUPS. Программа можно  использовать для предпросмотра или для печати буклетов.</translation>
+        <translation>Boomaga это виртуальный принтер для CUPS. Программу можно использовать для предпросмотра или печати буклетов.</translation>
     </message>
     <message>
         <source>Copyright: %1-%2 %3</source>
@@ -41,10 +41,6 @@
         <source>License: %1</source>
         <translation>Лицензия: %1</translation>
     </message>
-    <message>
-        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
-        <translation>Boomaga разрабатывается &lt;a %1&gt;командой Boomaga и помощниками &lt;/a&gt; на Github.</translation>
-    </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <translation>Если есть желание работать вместе с нашей командой разработчиков - &lt;a %1&gt;присоединяйтесь&lt;/a&gt;.</translation>
@@ -57,6 +53,10 @@
         <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
         <translation>Если Вы хотите помочь с переводом, мы будем рады видеть вас в нашей команде переводчиков на  &lt;a %1&gt;Transifex server&lt;/a&gt;.</translation>
     </message>
+    <message>
+        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
+        <translation>Boomaga разрабатывается &lt;a %1&gt;командой Boomaga и помощниками&lt;/a&gt; на GitHub.</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -80,6 +80,26 @@
         <source>Sheets per sub-booklet:</source>
         <translation>Листов в тетради:</translation>
     </message>
+    <message>
+        <source>Autosave your jobs every time you print.</source>
+        <translation>Автоматически сохранять задания после печати.</translation>
+    </message>
+    <message>
+        <source>AutoSave the recent sessions</source>
+        <translation>Автоматически сохранять сесии</translation>
+    </message>
+    <message>
+        <source>Allow negative page margins:</source>
+        <translation>Разрешать отрицательные поля:</translation>
+    </message>
+    <message>
+        <source>Select directory for saved jobs.</source>
+        <translation>Укажите директорию для сохранения.</translation>
+    </message>
+    <message>
+        <source>Directory for saved sessions:</source>
+        <translation>Директория для сохраненных сессий:</translation>
+    </message>
 </context>
 <context>
     <name>ExportToPdf</name>
@@ -101,7 +121,7 @@
     </message>
     <message>
         <source>Meta info</source>
-        <translation>Мета информация</translation>
+        <translation>Метаинформация</translation>
     </message>
     <message>
         <source>Author:</source>
@@ -115,10 +135,6 @@
         <source>Title:</source>
         <translation>Заголовок:</translation>
     </message>
-    <message utf8="true">
-        <source> The document’s title.</source>
-        <translation>Заголовок документа.</translation>
-    </message>
     <message>
         <source>Subject:</source>
         <translation>Тема:</translation>
@@ -141,7 +157,7 @@
     </message>
     <message>
         <source>Overwrite file?</source>
-        <translation>Переписать файл?</translation>
+        <translation>Перезаписать файл?</translation>
     </message>
     <message>
         <source>A file named &quot;%1&quot; already exists.
@@ -155,10 +171,10 @@ Are you sure you want to overwrite it?</source>
     </message>
 </context>
 <context>
-    <name>JobsListView</name>
+    <name>JobListView</name>
     <message>
-        <source>( %1 pages )</source>
-        <translation>( %1 стр.) </translation>
+        <source>%1 pages</source>
+        <translation>%1 страниц</translation>
     </message>
 </context>
 <context>
@@ -175,10 +191,6 @@ Are you sure you want to overwrite it?</source>
         <source>Help</source>
         <translation>Помощь</translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation>Опции</translation>
-    </message>
     <message>
         <source>Layout</source>
         <translation>Расположение</translation>
@@ -219,7 +231,7 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Toolbar</source>
-        <translation>тулбар</translation>
+        <translation>Панель инструментов</translation>
     </message>
     <message>
         <source>&amp;Print</source>
@@ -315,10 +327,6 @@ Are you sure you want to overwrite it?</source>
         <source>Insert blank page before this page</source>
         <translation>Вставить пустую страницу перед этой</translation>
     </message>
-    <message>
-        <source>Delete pages until the end of the job.</source>
-        <translation>Удалить страницы до конца задания. </translation>
-    </message>
     <message>
         <source>Save</source>
         <translation>Сохранить</translation>
@@ -416,18 +424,10 @@ Are you sure you want to overwrite it?</source>
         <source>Rotate job to the right</source>
         <translation>Повернуть задание по часовой стрелке</translation>
     </message>
-    <message>
-        <source>Delete job</source>
-        <translation>Удалить</translation>
-    </message>
     <message>
         <source>Job title:</source>
         <translation>Имя задания:</translation>
     </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation>&amp;Экспортировать...</translation>
-    </message>
     <message>
         <source>Export the project to PDF</source>
         <translation>Экспортировать проект в PDF</translation>
@@ -460,6 +460,63 @@ Are you sure you want to overwrite it?</source>
         <source>Ctrl+Shift+P</source>
         <translation>Ctrl+Shift+P</translation>
     </message>
+    <message>
+        <source>Sub-booklets</source>
+        <translation>Тетради</translation>
+    </message>
+    <message>
+        <source>Undo delete page</source>
+        <translation>Отменить удаление страниц</translation>
+    </message>
+    <message>
+        <source>Page %1 of %2</source>
+        <comment>Status bar</comment>
+        <translation>Стр. %1 из %2</translation>
+    </message>
+    <message>
+        <source>Recent files</source>
+        <translation>Недавние файлы</translation>
+    </message>
+    <message>
+        <source>&amp;Edit page</source>
+        <translation>Редактирование &amp;страницы</translation>
+    </message>
+    <message>
+        <source>Edit &amp;job</source>
+        <translation>Редактирование &amp;задания</translation>
+    </message>
+    <message>
+        <source>&amp;Export to PDF...</source>
+        <translation>&amp;Экспортировать в PDF...</translation>
+    </message>
+    <message>
+        <source>Delete pages until the end of the job</source>
+        <translation>Удалить страницы до конца задания. </translation>
+    </message>
+    <message>
+        <source>Delete current job</source>
+        <translation>Удалить текущее задание</translation>
+    </message>
+    <message>
+        <source>Auto saving</source>
+        <translation>Авто сохраниение</translation>
+    </message>
+    <message>
+        <source>I can&apos;t create directory &quot;%1&quot;</source>
+        <translation>Не получилось создать директорию &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <source>%1 %2: Page %3</source>
+        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
+        <translation>%1 %2: страница %3</translation>
+    </message>
+</context>
+<context>
+    <name>PdfMerger</name>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -471,6 +528,10 @@ Are you sure you want to overwrite it?</source>
         <source>Number of copies:</source>
         <translation>Количество копий:</translation>
     </message>
+    <message>
+        <source>Collate copies:</source>
+        <translation>Разобрать по копиям:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -498,10 +559,6 @@ Are you sure you want to overwrite it?</source>
         <source>Top:</source>
         <translation>Верхнее:</translation>
     </message>
-    <message>
-        <source>Duplex:</source>
-        <translation>Дуплекс</translation>
-    </message>
     <message>
         <source>Draw border</source>
         <translation>Печатать рамку</translation>
@@ -520,7 +577,7 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>Manual without reverse</source>
-        <translation>Вручную без изменениея порядка</translation>
+        <translation>Вручную без изменения порядка</translation>
     </message>
     <message>
         <source>Preferences of &quot;%1&quot;</source>
@@ -547,6 +604,38 @@ Are you sure you want to overwrite it?</source>
         <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
         <translation>Профиль %1</translation>
     </message>
+    <message>
+        <source>Color mode:</source>
+        <translation>Режим цвета:</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>По умолчанию</translation>
+    </message>
+    <message>
+        <source>Force grayscale</source>
+        <translation>Принудительно в сером</translation>
+    </message>
+    <message>
+        <source>Force color</source>
+        <translation>Принудительно в цвете</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Настройки</translation>
+    </message>
+    <message>
+        <source>Print on both sides</source>
+        <translation>Двусторонняя печать</translation>
+    </message>
+    <message>
+        <source>Flip on short edge</source>
+        <translation>Переплет по короткой стороне</translation>
+    </message>
+    <message>
+        <source>Flip on long edge</source>
+        <translation>Переплет по длинной стороне</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -559,9 +648,6 @@ Are you sure you want to overwrite it?</source>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Не получилось записать файл: &quot;%1&quot;</translation>
     </message>
-</context>
-<context>
-    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
         <translation>Не получилось открыть файл: &quot;%1&quot; (Нет такого файла или директории)</translation>
@@ -575,32 +661,23 @@ Are you sure you want to overwrite it?</source>
         <translation>Не получилось открыть файл: &quot;%1&quot;</translation>
     </message>
     <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
         <translation>Не получилось прочитать файл: &quot;%1&quot;, файл испорчен или файлы такого типа не поддерживаются.</translation>
     </message>
 </context>
 <context>
-    <name>QObject</name>
-    <message>
-        <source>PDF file &quot;%1&quot; is damaged.</source>
-        <translation>Похоже, PDF файл &quot;%1&quot; нездоров.</translation>
-    </message>
-    <message>
-        <source>PDF file &quot;%1&quot; is encripted.</source>
-        <translation>Похоже, PDF файл &quot;%1&quot; зашифрован.</translation>
-    </message>
+    <name>ProjectFile</name>
     <message>
         <source>I can&apos;t open file &quot;%1&quot;</source>
         <translation>Не получилось открыть файл: &quot;%1&quot;</translation>
     </message>
     <message>
-        <source>Print to file (PDF)</source>
-        <translation>Сохранить как PDF файл</translation>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
     </message>
+</context>
+<context>
+    <name>QObject</name>
     <message>
         <source>I can&apos;t read from file &apos;%1&apos;</source>
         <translation>Не получилось прочитать файл: &quot;%1&quot;</translation>
@@ -623,7 +700,18 @@ Are you sure you want to overwrite it?</source>
     <name>Settings</name>
     <message>
         <source>~/Untitled.pdf</source>
-        <translation>~/Безимянный.pdf</translation>
+        <translation>~/Безымянный.pdf</translation>
+    </message>
+</context>
+<context>
+    <name>SubBookletView</name>
+    <message>
+        <source>Sub-booklet %1</source>
+        <translation>Тетрадь %1</translation>
+    </message>
+    <message>
+        <source>%1 pages</source>
+        <translation>%1 страниц</translation>
     </message>
 </context>
 <context>
@@ -635,7 +723,7 @@ Are you sure you want to overwrite it?</source>
     <message>
         <source>Something is wrong. I can't find boomagamerger program.
 Please reinstall me.</source>
-        <translation>Шеф, все пропало! Я не могу найти программу с именем boomagamerger. Попробуй переставить меня.</translation>
+        <translation>Шеф, все пропало! Я не могу найти программу с именем boomagamerger. Попробуй переустановить меня.</translation>
     </message>
     <message>
         <source>I can&apos;t read file &apos;%1&apos;</source>
